# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientNamenodeProtocol.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Security_pb2 as Security__pb2
import hdfs_pb2 as hdfs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientNamenodeProtocol.proto',
  package='hadoop.hdfs',
  syntax='proto2',
  serialized_pb=_b('\n\x1c\x43lientNamenodeProtocol.proto\x12\x0bhadoop.hdfs\x1a\x0eSecurity.proto\x1a\nhdfs.proto\"L\n\x1dGetBlockLocationsRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x0e\n\x06offset\x18\x02 \x02(\x04\x12\x0e\n\x06length\x18\x03 \x02(\x04\"T\n\x1eGetBlockLocationsResponseProto\x12\x32\n\tlocations\x18\x01 \x01(\x0b\x32\x1f.hadoop.hdfs.LocatedBlocksProto\"\x1f\n\x1dGetServerDefaultsRequestProto\"\\\n\x1eGetServerDefaultsResponseProto\x12:\n\x0eserverDefaults\x18\x01 \x02(\x0b\x32\".hadoop.hdfs.FsServerDefaultsProto\"\xb7\x01\n\x12\x43reateRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12.\n\x06masked\x18\x02 \x02(\x0b\x32\x1e.hadoop.hdfs.FsPermissionProto\x12\x12\n\nclientName\x18\x03 \x02(\t\x12\x12\n\ncreateFlag\x18\x04 \x02(\r\x12\x14\n\x0c\x63reateParent\x18\x05 \x02(\x08\x12\x13\n\x0breplication\x18\x06 \x02(\r\x12\x11\n\tblockSize\x18\x07 \x02(\x04\"C\n\x13\x43reateResponseProto\x12,\n\x02\x66s\x18\x01 \x01(\x0b\x32 .hadoop.hdfs.HdfsFileStatusProto\"5\n\x12\x41ppendRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x12\n\nclientName\x18\x02 \x02(\t\"D\n\x13\x41ppendResponseProto\x12-\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\">\n\x1aSetReplicationRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x13\n\x0breplication\x18\x02 \x02(\r\"-\n\x1bSetReplicationResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"\\\n\x19SetPermissionRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x32\n\npermission\x18\x02 \x02(\x0b\x32\x1e.hadoop.hdfs.FsPermissionProto\"\x1c\n\x1aSetPermissionResponseProto\"H\n\x14SetOwnerRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x11\n\tgroupname\x18\x03 \x01(\t\"\x17\n\x15SetOwnerResponseProto\"c\n\x18\x41\x62\x61ndonBlockRequestProto\x12*\n\x01\x62\x18\x01 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x0b\n\x03src\x18\x02 \x02(\t\x12\x0e\n\x06holder\x18\x03 \x02(\t\"\x1b\n\x19\x41\x62\x61ndonBlockResponseProto\"\xc9\x01\n\x14\x41\x64\x64\x42lockRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x12\n\nclientName\x18\x02 \x02(\t\x12\x31\n\x08previous\x18\x03 \x01(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x34\n\x0c\x65xcludeNodes\x18\x04 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\x12\x11\n\x06\x66ileId\x18\x05 \x01(\x04:\x01\x30\x12\x14\n\x0c\x66\x61voredNodes\x18\x06 \x03(\t\"F\n\x15\x41\x64\x64\x42lockResponseProto\x12-\n\x05\x62lock\x18\x01 \x02(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\"\xf3\x01\n!GetAdditionalDatanodeRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12,\n\x03\x62lk\x18\x02 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x31\n\texistings\x18\x03 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\x12\x30\n\x08\x65xcludes\x18\x04 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\x12\x1a\n\x12numAdditionalNodes\x18\x05 \x02(\r\x12\x12\n\nclientName\x18\x06 \x02(\t\"S\n\"GetAdditionalDatanodeResponseProto\x12-\n\x05\x62lock\x18\x01 \x02(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\"y\n\x14\x43ompleteRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x12\n\nclientName\x18\x02 \x02(\t\x12-\n\x04last\x18\x03 \x01(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x11\n\x06\x66ileId\x18\x04 \x01(\x04:\x01\x30\"\'\n\x15\x43ompleteResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"M\n\x1bReportBadBlocksRequestProto\x12.\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\"\x1e\n\x1cReportBadBlocksResponseProto\"/\n\x12\x43oncatRequestProto\x12\x0b\n\x03trg\x18\x01 \x02(\t\x12\x0c\n\x04srcs\x18\x02 \x03(\t\"\x15\n\x13\x43oncatResponseProto\".\n\x12RenameRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x0b\n\x03\x64st\x18\x02 \x02(\t\"%\n\x13RenameResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"F\n\x13Rename2RequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x0b\n\x03\x64st\x18\x02 \x02(\t\x12\x15\n\roverwriteDest\x18\x03 \x02(\x08\"\x16\n\x14Rename2ResponseProto\"4\n\x12\x44\x65leteRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x11\n\trecursive\x18\x02 \x02(\x08\"%\n\x13\x44\x65leteResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"g\n\x12MkdirsRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12.\n\x06masked\x18\x02 \x02(\x0b\x32\x1e.hadoop.hdfs.FsPermissionProto\x12\x14\n\x0c\x63reateParent\x18\x03 \x02(\x08\"%\n\x13MkdirsResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"O\n\x16GetListingRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x12\n\nstartAfter\x18\x02 \x02(\x0c\x12\x14\n\x0cneedLocation\x18\x03 \x02(\x08\"N\n\x17GetListingResponseProto\x12\x33\n\x07\x64irList\x18\x01 \x01(\x0b\x32\".hadoop.hdfs.DirectoryListingProto\"(\n&GetSnapshottableDirListingRequestProto\"x\n\'GetSnapshottableDirListingResponseProto\x12M\n\x14snapshottableDirList\x18\x01 \x01(\x0b\x32/.hadoop.hdfs.SnapshottableDirectoryListingProto\"c\n!GetSnapshotDiffReportRequestProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\x12\x14\n\x0c\x66romSnapshot\x18\x02 \x02(\t\x12\x12\n\ntoSnapshot\x18\x03 \x02(\t\"^\n\"GetSnapshotDiffReportResponseProto\x12\x38\n\ndiffReport\x18\x01 \x02(\x0b\x32$.hadoop.hdfs.SnapshotDiffReportProto\",\n\x16RenewLeaseRequestProto\x12\x12\n\nclientName\x18\x01 \x02(\t\"\x19\n\x17RenewLeaseResponseProto\";\n\x18RecoverLeaseRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x12\n\nclientName\x18\x02 \x02(\t\"+\n\x19RecoverLeaseResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"\x19\n\x17GetFsStatusRequestProto\"\x96\x01\n\x17GetFsStatsResponseProto\x12\x10\n\x08\x63\x61pacity\x18\x01 \x02(\x04\x12\x0c\n\x04used\x18\x02 \x02(\x04\x12\x11\n\tremaining\x18\x03 \x02(\x04\x12\x18\n\x10under_replicated\x18\x04 \x02(\x04\x12\x16\n\x0e\x63orrupt_blocks\x18\x05 \x02(\x04\x12\x16\n\x0emissing_blocks\x18\x06 \x02(\x04\"S\n\x1dGetDatanodeReportRequestProto\x12\x32\n\x04type\x18\x01 \x02(\x0e\x32$.hadoop.hdfs.DatanodeReportTypeProto\"L\n\x1eGetDatanodeReportResponseProto\x12*\n\x02\x64i\x18\x01 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\"5\n!GetPreferredBlockSizeRequestProto\x12\x10\n\x08\x66ilename\x18\x01 \x02(\t\"3\n\"GetPreferredBlockSizeResponseProto\x12\r\n\x05\x62size\x18\x01 \x02(\x04\"c\n\x17SetSafeModeRequestProto\x12\x30\n\x06\x61\x63tion\x18\x01 \x02(\x0e\x32 .hadoop.hdfs.SafeModeActionProto\x12\x16\n\x07\x63hecked\x18\x02 \x01(\x08:\x05\x66\x61lse\"*\n\x18SetSafeModeResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"\x1b\n\x19SaveNamespaceRequestProto\"\x1c\n\x1aSaveNamespaceResponseProto\"\x17\n\x15RollEditsRequestProto\"0\n\x16RollEditsResponseProto\x12\x16\n\x0enewSegmentTxId\x18\x01 \x02(\x04\"/\n RestoreFailedStorageRequestProto\x12\x0b\n\x03\x61rg\x18\x01 \x02(\t\"3\n!RestoreFailedStorageResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"\x1a\n\x18RefreshNodesRequestProto\"\x1b\n\x19RefreshNodesResponseProto\"\x1d\n\x1b\x46inalizeUpgradeRequestProto\"\x1e\n\x1c\x46inalizeUpgradeResponseProto\"A\n!ListCorruptFileBlocksRequestProto\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\t\"Z\n\"ListCorruptFileBlocksResponseProto\x12\x34\n\x07\x63orrupt\x18\x01 \x02(\x0b\x32#.hadoop.hdfs.CorruptFileBlocksProto\"(\n\x14MetaSaveRequestProto\x12\x10\n\x08\x66ilename\x18\x01 \x02(\t\"\x17\n\x15MetaSaveResponseProto\"&\n\x17GetFileInfoRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\"H\n\x18GetFileInfoResponseProto\x12,\n\x02\x66s\x18\x01 \x01(\x0b\x32 .hadoop.hdfs.HdfsFileStatusProto\"\'\n\x18IsFileClosedRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\"+\n\x19IsFileClosedResponseProto\x12\x0e\n\x06result\x18\x01 \x02(\x08\"*\n\x1bGetFileLinkInfoRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\"L\n\x1cGetFileLinkInfoResponseProto\x12,\n\x02\x66s\x18\x01 \x01(\x0b\x32 .hadoop.hdfs.HdfsFileStatusProto\"-\n\x1dGetContentSummaryRequestProto\x12\x0c\n\x04path\x18\x01 \x02(\t\"S\n\x1eGetContentSummaryResponseProto\x12\x31\n\x07summary\x18\x01 \x02(\x0b\x32 .hadoop.hdfs.ContentSummaryProto\"T\n\x14SetQuotaRequestProto\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x16\n\x0enamespaceQuota\x18\x02 \x02(\x04\x12\x16\n\x0e\x64iskspaceQuota\x18\x03 \x02(\x04\"\x17\n\x15SetQuotaResponseProto\"M\n\x11\x46syncRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\x0e\n\x06\x63lient\x18\x02 \x02(\t\x12\x1b\n\x0flastBlockLength\x18\x03 \x01(\x12:\x02-1\"\x14\n\x12\x46syncResponseProto\"A\n\x14SetTimesRequestProto\x12\x0b\n\x03src\x18\x01 \x02(\t\x12\r\n\x05mtime\x18\x02 \x02(\x04\x12\r\n\x05\x61time\x18\x03 \x02(\x04\"\x17\n\x15SetTimesResponseProto\"\x80\x01\n\x19\x43reateSymlinkRequestProto\x12\x0e\n\x06target\x18\x01 \x02(\t\x12\x0c\n\x04link\x18\x02 \x02(\t\x12/\n\x07\x64irPerm\x18\x03 \x02(\x0b\x32\x1e.hadoop.hdfs.FsPermissionProto\x12\x14\n\x0c\x63reateParent\x18\x04 \x02(\x08\"\x1c\n\x1a\x43reateSymlinkResponseProto\")\n\x19GetLinkTargetRequestProto\x12\x0c\n\x04path\x18\x01 \x02(\t\"0\n\x1aGetLinkTargetResponseProto\x12\x12\n\ntargetPath\x18\x01 \x01(\t\"h\n\"UpdateBlockForPipelineRequestProto\x12.\n\x05\x62lock\x18\x01 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x12\n\nclientName\x18\x02 \x02(\t\"T\n#UpdateBlockForPipelineResponseProto\x12-\n\x05\x62lock\x18\x01 \x02(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\"\xc6\x01\n\x1aUpdatePipelineRequestProto\x12\x12\n\nclientName\x18\x01 \x02(\t\x12\x31\n\x08oldBlock\x18\x02 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x31\n\x08newBlock\x18\x03 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12.\n\x08newNodes\x18\x04 \x03(\x0b\x32\x1c.hadoop.hdfs.DatanodeIDProto\"\x1d\n\x1bUpdatePipelineResponseProto\"5\n SetBalancerBandwidthRequestProto\x12\x11\n\tbandwidth\x18\x01 \x02(\x03\"#\n!SetBalancerBandwidthResponseProto\"\"\n GetDataEncryptionKeyRequestProto\"c\n!GetDataEncryptionKeyResponseProto\x12>\n\x11\x64\x61taEncryptionKey\x18\x01 \x01(\x0b\x32#.hadoop.hdfs.DataEncryptionKeyProto\"H\n\x1a\x43reateSnapshotRequestProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\x12\x14\n\x0csnapshotName\x18\x02 \x01(\t\"3\n\x1b\x43reateSnapshotResponseProto\x12\x14\n\x0csnapshotPath\x18\x01 \x02(\t\"d\n\x1aRenameSnapshotRequestProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\x12\x17\n\x0fsnapshotOldName\x18\x02 \x02(\t\x12\x17\n\x0fsnapshotNewName\x18\x03 \x02(\t\"\x1d\n\x1bRenameSnapshotResponseProto\"1\n\x19\x41llowSnapshotRequestProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\"\x1c\n\x1a\x41llowSnapshotResponseProto\"4\n\x1c\x44isallowSnapshotRequestProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\"\x1f\n\x1d\x44isallowSnapshotResponseProto\"H\n\x1a\x44\x65leteSnapshotRequestProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\x12\x14\n\x0csnapshotName\x18\x02 \x02(\t\"\x1d\n\x1b\x44\x65leteSnapshotResponseProto*8\n\x0f\x43reateFlagProto\x12\n\n\x06\x43REATE\x10\x01\x12\r\n\tOVERWRITE\x10\x02\x12\n\n\x06\x41PPEND\x10\x04*6\n\x17\x44\x61tanodeReportTypeProto\x12\x07\n\x03\x41LL\x10\x01\x12\x08\n\x04LIVE\x10\x02\x12\x08\n\x04\x44\x45\x41\x44\x10\x03*O\n\x13SafeModeActionProto\x12\x12\n\x0eSAFEMODE_LEAVE\x10\x01\x12\x12\n\x0eSAFEMODE_ENTER\x10\x02\x12\x10\n\x0cSAFEMODE_GET\x10\x03\x32\x88*\n\x16\x43lientNamenodeProtocol\x12l\n\x11getBlockLocations\x12*.hadoop.hdfs.GetBlockLocationsRequestProto\x1a+.hadoop.hdfs.GetBlockLocationsResponseProto\x12l\n\x11getServerDefaults\x12*.hadoop.hdfs.GetServerDefaultsRequestProto\x1a+.hadoop.hdfs.GetServerDefaultsResponseProto\x12K\n\x06\x63reate\x12\x1f.hadoop.hdfs.CreateRequestProto\x1a .hadoop.hdfs.CreateResponseProto\x12K\n\x06\x61ppend\x12\x1f.hadoop.hdfs.AppendRequestProto\x1a .hadoop.hdfs.AppendResponseProto\x12\x63\n\x0esetReplication\x12\'.hadoop.hdfs.SetReplicationRequestProto\x1a(.hadoop.hdfs.SetReplicationResponseProto\x12`\n\rsetPermission\x12&.hadoop.hdfs.SetPermissionRequestProto\x1a\'.hadoop.hdfs.SetPermissionResponseProto\x12Q\n\x08setOwner\x12!.hadoop.hdfs.SetOwnerRequestProto\x1a\".hadoop.hdfs.SetOwnerResponseProto\x12]\n\x0c\x61\x62\x61ndonBlock\x12%.hadoop.hdfs.AbandonBlockRequestProto\x1a&.hadoop.hdfs.AbandonBlockResponseProto\x12Q\n\x08\x61\x64\x64\x42lock\x12!.hadoop.hdfs.AddBlockRequestProto\x1a\".hadoop.hdfs.AddBlockResponseProto\x12x\n\x15getAdditionalDatanode\x12..hadoop.hdfs.GetAdditionalDatanodeRequestProto\x1a/.hadoop.hdfs.GetAdditionalDatanodeResponseProto\x12Q\n\x08\x63omplete\x12!.hadoop.hdfs.CompleteRequestProto\x1a\".hadoop.hdfs.CompleteResponseProto\x12\x66\n\x0freportBadBlocks\x12(.hadoop.hdfs.ReportBadBlocksRequestProto\x1a).hadoop.hdfs.ReportBadBlocksResponseProto\x12K\n\x06\x63oncat\x12\x1f.hadoop.hdfs.ConcatRequestProto\x1a .hadoop.hdfs.ConcatResponseProto\x12K\n\x06rename\x12\x1f.hadoop.hdfs.RenameRequestProto\x1a .hadoop.hdfs.RenameResponseProto\x12N\n\x07rename2\x12 .hadoop.hdfs.Rename2RequestProto\x1a!.hadoop.hdfs.Rename2ResponseProto\x12K\n\x06\x64\x65lete\x12\x1f.hadoop.hdfs.DeleteRequestProto\x1a .hadoop.hdfs.DeleteResponseProto\x12K\n\x06mkdirs\x12\x1f.hadoop.hdfs.MkdirsRequestProto\x1a .hadoop.hdfs.MkdirsResponseProto\x12W\n\ngetListing\x12#.hadoop.hdfs.GetListingRequestProto\x1a$.hadoop.hdfs.GetListingResponseProto\x12W\n\nrenewLease\x12#.hadoop.hdfs.RenewLeaseRequestProto\x1a$.hadoop.hdfs.RenewLeaseResponseProto\x12]\n\x0crecoverLease\x12%.hadoop.hdfs.RecoverLeaseRequestProto\x1a&.hadoop.hdfs.RecoverLeaseResponseProto\x12X\n\ngetFsStats\x12$.hadoop.hdfs.GetFsStatusRequestProto\x1a$.hadoop.hdfs.GetFsStatsResponseProto\x12l\n\x11getDatanodeReport\x12*.hadoop.hdfs.GetDatanodeReportRequestProto\x1a+.hadoop.hdfs.GetDatanodeReportResponseProto\x12x\n\x15getPreferredBlockSize\x12..hadoop.hdfs.GetPreferredBlockSizeRequestProto\x1a/.hadoop.hdfs.GetPreferredBlockSizeResponseProto\x12Z\n\x0bsetSafeMode\x12$.hadoop.hdfs.SetSafeModeRequestProto\x1a%.hadoop.hdfs.SetSafeModeResponseProto\x12`\n\rsaveNamespace\x12&.hadoop.hdfs.SaveNamespaceRequestProto\x1a\'.hadoop.hdfs.SaveNamespaceResponseProto\x12T\n\trollEdits\x12\".hadoop.hdfs.RollEditsRequestProto\x1a#.hadoop.hdfs.RollEditsResponseProto\x12u\n\x14restoreFailedStorage\x12-.hadoop.hdfs.RestoreFailedStorageRequestProto\x1a..hadoop.hdfs.RestoreFailedStorageResponseProto\x12]\n\x0crefreshNodes\x12%.hadoop.hdfs.RefreshNodesRequestProto\x1a&.hadoop.hdfs.RefreshNodesResponseProto\x12\x66\n\x0f\x66inalizeUpgrade\x12(.hadoop.hdfs.FinalizeUpgradeRequestProto\x1a).hadoop.hdfs.FinalizeUpgradeResponseProto\x12x\n\x15listCorruptFileBlocks\x12..hadoop.hdfs.ListCorruptFileBlocksRequestProto\x1a/.hadoop.hdfs.ListCorruptFileBlocksResponseProto\x12Q\n\x08metaSave\x12!.hadoop.hdfs.MetaSaveRequestProto\x1a\".hadoop.hdfs.MetaSaveResponseProto\x12Z\n\x0bgetFileInfo\x12$.hadoop.hdfs.GetFileInfoRequestProto\x1a%.hadoop.hdfs.GetFileInfoResponseProto\x12\x66\n\x0fgetFileLinkInfo\x12(.hadoop.hdfs.GetFileLinkInfoRequestProto\x1a).hadoop.hdfs.GetFileLinkInfoResponseProto\x12l\n\x11getContentSummary\x12*.hadoop.hdfs.GetContentSummaryRequestProto\x1a+.hadoop.hdfs.GetContentSummaryResponseProto\x12Q\n\x08setQuota\x12!.hadoop.hdfs.SetQuotaRequestProto\x1a\".hadoop.hdfs.SetQuotaResponseProto\x12H\n\x05\x66sync\x12\x1e.hadoop.hdfs.FsyncRequestProto\x1a\x1f.hadoop.hdfs.FsyncResponseProto\x12Q\n\x08setTimes\x12!.hadoop.hdfs.SetTimesRequestProto\x1a\".hadoop.hdfs.SetTimesResponseProto\x12`\n\rcreateSymlink\x12&.hadoop.hdfs.CreateSymlinkRequestProto\x1a\'.hadoop.hdfs.CreateSymlinkResponseProto\x12`\n\rgetLinkTarget\x12&.hadoop.hdfs.GetLinkTargetRequestProto\x1a\'.hadoop.hdfs.GetLinkTargetResponseProto\x12{\n\x16updateBlockForPipeline\x12/.hadoop.hdfs.UpdateBlockForPipelineRequestProto\x1a\x30.hadoop.hdfs.UpdateBlockForPipelineResponseProto\x12\x63\n\x0eupdatePipeline\x12\'.hadoop.hdfs.UpdatePipelineRequestProto\x1a(.hadoop.hdfs.UpdatePipelineResponseProto\x12s\n\x12getDelegationToken\x12-.hadoop.common.GetDelegationTokenRequestProto\x1a..hadoop.common.GetDelegationTokenResponseProto\x12y\n\x14renewDelegationToken\x12/.hadoop.common.RenewDelegationTokenRequestProto\x1a\x30.hadoop.common.RenewDelegationTokenResponseProto\x12|\n\x15\x63\x61ncelDelegationToken\x12\x30.hadoop.common.CancelDelegationTokenRequestProto\x1a\x31.hadoop.common.CancelDelegationTokenResponseProto\x12u\n\x14setBalancerBandwidth\x12-.hadoop.hdfs.SetBalancerBandwidthRequestProto\x1a..hadoop.hdfs.SetBalancerBandwidthResponseProto\x12u\n\x14getDataEncryptionKey\x12-.hadoop.hdfs.GetDataEncryptionKeyRequestProto\x1a..hadoop.hdfs.GetDataEncryptionKeyResponseProto\x12\x63\n\x0e\x63reateSnapshot\x12\'.hadoop.hdfs.CreateSnapshotRequestProto\x1a(.hadoop.hdfs.CreateSnapshotResponseProto\x12\x63\n\x0erenameSnapshot\x12\'.hadoop.hdfs.RenameSnapshotRequestProto\x1a(.hadoop.hdfs.RenameSnapshotResponseProto\x12`\n\rallowSnapshot\x12&.hadoop.hdfs.AllowSnapshotRequestProto\x1a\'.hadoop.hdfs.AllowSnapshotResponseProto\x12i\n\x10\x64isallowSnapshot\x12).hadoop.hdfs.DisallowSnapshotRequestProto\x1a*.hadoop.hdfs.DisallowSnapshotResponseProto\x12\x87\x01\n\x1agetSnapshottableDirListing\x12\x33.hadoop.hdfs.GetSnapshottableDirListingRequestProto\x1a\x34.hadoop.hdfs.GetSnapshottableDirListingResponseProto\x12\x63\n\x0e\x64\x65leteSnapshot\x12\'.hadoop.hdfs.DeleteSnapshotRequestProto\x1a(.hadoop.hdfs.DeleteSnapshotResponseProto\x12x\n\x15getSnapshotDiffReport\x12..hadoop.hdfs.GetSnapshotDiffReportRequestProto\x1a/.hadoop.hdfs.GetSnapshotDiffReportResponseProto\x12]\n\x0cisFileClosed\x12%.hadoop.hdfs.IsFileClosedRequestProto\x1a&.hadoop.hdfs.IsFileClosedResponseProtoBN\n%org.apache.hadoop.hdfs.protocol.protoB\x1c\x43lientNamenodeProtocolProtos\x88\x01\x01\x90\x01\x01\xa0\x01\x01')
  ,
  dependencies=[Security__pb2.DESCRIPTOR,hdfs__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CREATEFLAGPROTO = _descriptor.EnumDescriptor(
  name='CreateFlagProto',
  full_name='hadoop.hdfs.CreateFlagProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVERWRITE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPEND', index=2, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6659,
  serialized_end=6715,
)
_sym_db.RegisterEnumDescriptor(_CREATEFLAGPROTO)

CreateFlagProto = enum_type_wrapper.EnumTypeWrapper(_CREATEFLAGPROTO)
_DATANODEREPORTTYPEPROTO = _descriptor.EnumDescriptor(
  name='DatanodeReportTypeProto',
  full_name='hadoop.hdfs.DatanodeReportTypeProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIVE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6717,
  serialized_end=6771,
)
_sym_db.RegisterEnumDescriptor(_DATANODEREPORTTYPEPROTO)

DatanodeReportTypeProto = enum_type_wrapper.EnumTypeWrapper(_DATANODEREPORTTYPEPROTO)
_SAFEMODEACTIONPROTO = _descriptor.EnumDescriptor(
  name='SafeModeActionProto',
  full_name='hadoop.hdfs.SafeModeActionProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SAFEMODE_LEAVE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAFEMODE_ENTER', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAFEMODE_GET', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6773,
  serialized_end=6852,
)
_sym_db.RegisterEnumDescriptor(_SAFEMODEACTIONPROTO)

SafeModeActionProto = enum_type_wrapper.EnumTypeWrapper(_SAFEMODEACTIONPROTO)
CREATE = 1
OVERWRITE = 2
APPEND = 4
ALL = 1
LIVE = 2
DEAD = 3
SAFEMODE_LEAVE = 1
SAFEMODE_ENTER = 2
SAFEMODE_GET = 3



_GETBLOCKLOCATIONSREQUESTPROTO = _descriptor.Descriptor(
  name='GetBlockLocationsRequestProto',
  full_name='hadoop.hdfs.GetBlockLocationsRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.GetBlockLocationsRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='hadoop.hdfs.GetBlockLocationsRequestProto.offset', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='length', full_name='hadoop.hdfs.GetBlockLocationsRequestProto.length', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=149,
)


_GETBLOCKLOCATIONSRESPONSEPROTO = _descriptor.Descriptor(
  name='GetBlockLocationsResponseProto',
  full_name='hadoop.hdfs.GetBlockLocationsResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locations', full_name='hadoop.hdfs.GetBlockLocationsResponseProto.locations', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=235,
)


_GETSERVERDEFAULTSREQUESTPROTO = _descriptor.Descriptor(
  name='GetServerDefaultsRequestProto',
  full_name='hadoop.hdfs.GetServerDefaultsRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=268,
)


_GETSERVERDEFAULTSRESPONSEPROTO = _descriptor.Descriptor(
  name='GetServerDefaultsResponseProto',
  full_name='hadoop.hdfs.GetServerDefaultsResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverDefaults', full_name='hadoop.hdfs.GetServerDefaultsResponseProto.serverDefaults', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=362,
)


_CREATEREQUESTPROTO = _descriptor.Descriptor(
  name='CreateRequestProto',
  full_name='hadoop.hdfs.CreateRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.CreateRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='masked', full_name='hadoop.hdfs.CreateRequestProto.masked', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.CreateRequestProto.clientName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createFlag', full_name='hadoop.hdfs.CreateRequestProto.createFlag', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createParent', full_name='hadoop.hdfs.CreateRequestProto.createParent', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replication', full_name='hadoop.hdfs.CreateRequestProto.replication', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='hadoop.hdfs.CreateRequestProto.blockSize', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=548,
)


_CREATERESPONSEPROTO = _descriptor.Descriptor(
  name='CreateResponseProto',
  full_name='hadoop.hdfs.CreateResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fs', full_name='hadoop.hdfs.CreateResponseProto.fs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=617,
)


_APPENDREQUESTPROTO = _descriptor.Descriptor(
  name='AppendRequestProto',
  full_name='hadoop.hdfs.AppendRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.AppendRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.AppendRequestProto.clientName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=672,
)


_APPENDRESPONSEPROTO = _descriptor.Descriptor(
  name='AppendResponseProto',
  full_name='hadoop.hdfs.AppendResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.AppendResponseProto.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=742,
)


_SETREPLICATIONREQUESTPROTO = _descriptor.Descriptor(
  name='SetReplicationRequestProto',
  full_name='hadoop.hdfs.SetReplicationRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.SetReplicationRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replication', full_name='hadoop.hdfs.SetReplicationRequestProto.replication', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=806,
)


_SETREPLICATIONRESPONSEPROTO = _descriptor.Descriptor(
  name='SetReplicationResponseProto',
  full_name='hadoop.hdfs.SetReplicationResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.SetReplicationResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=853,
)


_SETPERMISSIONREQUESTPROTO = _descriptor.Descriptor(
  name='SetPermissionRequestProto',
  full_name='hadoop.hdfs.SetPermissionRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.SetPermissionRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='hadoop.hdfs.SetPermissionRequestProto.permission', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=947,
)


_SETPERMISSIONRESPONSEPROTO = _descriptor.Descriptor(
  name='SetPermissionResponseProto',
  full_name='hadoop.hdfs.SetPermissionResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=977,
)


_SETOWNERREQUESTPROTO = _descriptor.Descriptor(
  name='SetOwnerRequestProto',
  full_name='hadoop.hdfs.SetOwnerRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.SetOwnerRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='hadoop.hdfs.SetOwnerRequestProto.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='groupname', full_name='hadoop.hdfs.SetOwnerRequestProto.groupname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1051,
)


_SETOWNERRESPONSEPROTO = _descriptor.Descriptor(
  name='SetOwnerResponseProto',
  full_name='hadoop.hdfs.SetOwnerResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1053,
  serialized_end=1076,
)


_ABANDONBLOCKREQUESTPROTO = _descriptor.Descriptor(
  name='AbandonBlockRequestProto',
  full_name='hadoop.hdfs.AbandonBlockRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b', full_name='hadoop.hdfs.AbandonBlockRequestProto.b', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.AbandonBlockRequestProto.src', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='holder', full_name='hadoop.hdfs.AbandonBlockRequestProto.holder', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1177,
)


_ABANDONBLOCKRESPONSEPROTO = _descriptor.Descriptor(
  name='AbandonBlockResponseProto',
  full_name='hadoop.hdfs.AbandonBlockResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1206,
)


_ADDBLOCKREQUESTPROTO = _descriptor.Descriptor(
  name='AddBlockRequestProto',
  full_name='hadoop.hdfs.AddBlockRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.AddBlockRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.AddBlockRequestProto.clientName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous', full_name='hadoop.hdfs.AddBlockRequestProto.previous', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='excludeNodes', full_name='hadoop.hdfs.AddBlockRequestProto.excludeNodes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fileId', full_name='hadoop.hdfs.AddBlockRequestProto.fileId', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='favoredNodes', full_name='hadoop.hdfs.AddBlockRequestProto.favoredNodes', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1209,
  serialized_end=1410,
)


_ADDBLOCKRESPONSEPROTO = _descriptor.Descriptor(
  name='AddBlockResponseProto',
  full_name='hadoop.hdfs.AddBlockResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.AddBlockResponseProto.block', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1412,
  serialized_end=1482,
)


_GETADDITIONALDATANODEREQUESTPROTO = _descriptor.Descriptor(
  name='GetAdditionalDatanodeRequestProto',
  full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blk', full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto.blk', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='existings', full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto.existings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='excludes', full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto.excludes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numAdditionalNodes', full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto.numAdditionalNodes', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.GetAdditionalDatanodeRequestProto.clientName', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1485,
  serialized_end=1728,
)


_GETADDITIONALDATANODERESPONSEPROTO = _descriptor.Descriptor(
  name='GetAdditionalDatanodeResponseProto',
  full_name='hadoop.hdfs.GetAdditionalDatanodeResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.GetAdditionalDatanodeResponseProto.block', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1813,
)


_COMPLETEREQUESTPROTO = _descriptor.Descriptor(
  name='CompleteRequestProto',
  full_name='hadoop.hdfs.CompleteRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.CompleteRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.CompleteRequestProto.clientName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last', full_name='hadoop.hdfs.CompleteRequestProto.last', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fileId', full_name='hadoop.hdfs.CompleteRequestProto.fileId', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1936,
)


_COMPLETERESPONSEPROTO = _descriptor.Descriptor(
  name='CompleteResponseProto',
  full_name='hadoop.hdfs.CompleteResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.CompleteResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=1977,
)


_REPORTBADBLOCKSREQUESTPROTO = _descriptor.Descriptor(
  name='ReportBadBlocksRequestProto',
  full_name='hadoop.hdfs.ReportBadBlocksRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='hadoop.hdfs.ReportBadBlocksRequestProto.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1979,
  serialized_end=2056,
)


_REPORTBADBLOCKSRESPONSEPROTO = _descriptor.Descriptor(
  name='ReportBadBlocksResponseProto',
  full_name='hadoop.hdfs.ReportBadBlocksResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2058,
  serialized_end=2088,
)


_CONCATREQUESTPROTO = _descriptor.Descriptor(
  name='ConcatRequestProto',
  full_name='hadoop.hdfs.ConcatRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trg', full_name='hadoop.hdfs.ConcatRequestProto.trg', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='srcs', full_name='hadoop.hdfs.ConcatRequestProto.srcs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2090,
  serialized_end=2137,
)


_CONCATRESPONSEPROTO = _descriptor.Descriptor(
  name='ConcatResponseProto',
  full_name='hadoop.hdfs.ConcatResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2139,
  serialized_end=2160,
)


_RENAMEREQUESTPROTO = _descriptor.Descriptor(
  name='RenameRequestProto',
  full_name='hadoop.hdfs.RenameRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.RenameRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dst', full_name='hadoop.hdfs.RenameRequestProto.dst', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2162,
  serialized_end=2208,
)


_RENAMERESPONSEPROTO = _descriptor.Descriptor(
  name='RenameResponseProto',
  full_name='hadoop.hdfs.RenameResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.RenameResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2210,
  serialized_end=2247,
)


_RENAME2REQUESTPROTO = _descriptor.Descriptor(
  name='Rename2RequestProto',
  full_name='hadoop.hdfs.Rename2RequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.Rename2RequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dst', full_name='hadoop.hdfs.Rename2RequestProto.dst', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overwriteDest', full_name='hadoop.hdfs.Rename2RequestProto.overwriteDest', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2249,
  serialized_end=2319,
)


_RENAME2RESPONSEPROTO = _descriptor.Descriptor(
  name='Rename2ResponseProto',
  full_name='hadoop.hdfs.Rename2ResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2321,
  serialized_end=2343,
)


_DELETEREQUESTPROTO = _descriptor.Descriptor(
  name='DeleteRequestProto',
  full_name='hadoop.hdfs.DeleteRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.DeleteRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='hadoop.hdfs.DeleteRequestProto.recursive', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2345,
  serialized_end=2397,
)


_DELETERESPONSEPROTO = _descriptor.Descriptor(
  name='DeleteResponseProto',
  full_name='hadoop.hdfs.DeleteResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.DeleteResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2436,
)


_MKDIRSREQUESTPROTO = _descriptor.Descriptor(
  name='MkdirsRequestProto',
  full_name='hadoop.hdfs.MkdirsRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.MkdirsRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='masked', full_name='hadoop.hdfs.MkdirsRequestProto.masked', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createParent', full_name='hadoop.hdfs.MkdirsRequestProto.createParent', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2438,
  serialized_end=2541,
)


_MKDIRSRESPONSEPROTO = _descriptor.Descriptor(
  name='MkdirsResponseProto',
  full_name='hadoop.hdfs.MkdirsResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.MkdirsResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2543,
  serialized_end=2580,
)


_GETLISTINGREQUESTPROTO = _descriptor.Descriptor(
  name='GetListingRequestProto',
  full_name='hadoop.hdfs.GetListingRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.GetListingRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startAfter', full_name='hadoop.hdfs.GetListingRequestProto.startAfter', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='needLocation', full_name='hadoop.hdfs.GetListingRequestProto.needLocation', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2582,
  serialized_end=2661,
)


_GETLISTINGRESPONSEPROTO = _descriptor.Descriptor(
  name='GetListingResponseProto',
  full_name='hadoop.hdfs.GetListingResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dirList', full_name='hadoop.hdfs.GetListingResponseProto.dirList', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2663,
  serialized_end=2741,
)


_GETSNAPSHOTTABLEDIRLISTINGREQUESTPROTO = _descriptor.Descriptor(
  name='GetSnapshottableDirListingRequestProto',
  full_name='hadoop.hdfs.GetSnapshottableDirListingRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2743,
  serialized_end=2783,
)


_GETSNAPSHOTTABLEDIRLISTINGRESPONSEPROTO = _descriptor.Descriptor(
  name='GetSnapshottableDirListingResponseProto',
  full_name='hadoop.hdfs.GetSnapshottableDirListingResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshottableDirList', full_name='hadoop.hdfs.GetSnapshottableDirListingResponseProto.snapshottableDirList', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2785,
  serialized_end=2905,
)


_GETSNAPSHOTDIFFREPORTREQUESTPROTO = _descriptor.Descriptor(
  name='GetSnapshotDiffReportRequestProto',
  full_name='hadoop.hdfs.GetSnapshotDiffReportRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.GetSnapshotDiffReportRequestProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fromSnapshot', full_name='hadoop.hdfs.GetSnapshotDiffReportRequestProto.fromSnapshot', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='toSnapshot', full_name='hadoop.hdfs.GetSnapshotDiffReportRequestProto.toSnapshot', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2907,
  serialized_end=3006,
)


_GETSNAPSHOTDIFFREPORTRESPONSEPROTO = _descriptor.Descriptor(
  name='GetSnapshotDiffReportResponseProto',
  full_name='hadoop.hdfs.GetSnapshotDiffReportResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='diffReport', full_name='hadoop.hdfs.GetSnapshotDiffReportResponseProto.diffReport', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3008,
  serialized_end=3102,
)


_RENEWLEASEREQUESTPROTO = _descriptor.Descriptor(
  name='RenewLeaseRequestProto',
  full_name='hadoop.hdfs.RenewLeaseRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.RenewLeaseRequestProto.clientName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3104,
  serialized_end=3148,
)


_RENEWLEASERESPONSEPROTO = _descriptor.Descriptor(
  name='RenewLeaseResponseProto',
  full_name='hadoop.hdfs.RenewLeaseResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3150,
  serialized_end=3175,
)


_RECOVERLEASEREQUESTPROTO = _descriptor.Descriptor(
  name='RecoverLeaseRequestProto',
  full_name='hadoop.hdfs.RecoverLeaseRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.RecoverLeaseRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.RecoverLeaseRequestProto.clientName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3177,
  serialized_end=3236,
)


_RECOVERLEASERESPONSEPROTO = _descriptor.Descriptor(
  name='RecoverLeaseResponseProto',
  full_name='hadoop.hdfs.RecoverLeaseResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.RecoverLeaseResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3238,
  serialized_end=3281,
)


_GETFSSTATUSREQUESTPROTO = _descriptor.Descriptor(
  name='GetFsStatusRequestProto',
  full_name='hadoop.hdfs.GetFsStatusRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3283,
  serialized_end=3308,
)


_GETFSSTATSRESPONSEPROTO = _descriptor.Descriptor(
  name='GetFsStatsResponseProto',
  full_name='hadoop.hdfs.GetFsStatsResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='capacity', full_name='hadoop.hdfs.GetFsStatsResponseProto.capacity', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='used', full_name='hadoop.hdfs.GetFsStatsResponseProto.used', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remaining', full_name='hadoop.hdfs.GetFsStatsResponseProto.remaining', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='under_replicated', full_name='hadoop.hdfs.GetFsStatsResponseProto.under_replicated', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='corrupt_blocks', full_name='hadoop.hdfs.GetFsStatsResponseProto.corrupt_blocks', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='missing_blocks', full_name='hadoop.hdfs.GetFsStatsResponseProto.missing_blocks', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3311,
  serialized_end=3461,
)


_GETDATANODEREPORTREQUESTPROTO = _descriptor.Descriptor(
  name='GetDatanodeReportRequestProto',
  full_name='hadoop.hdfs.GetDatanodeReportRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='hadoop.hdfs.GetDatanodeReportRequestProto.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3463,
  serialized_end=3546,
)


_GETDATANODEREPORTRESPONSEPROTO = _descriptor.Descriptor(
  name='GetDatanodeReportResponseProto',
  full_name='hadoop.hdfs.GetDatanodeReportResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='di', full_name='hadoop.hdfs.GetDatanodeReportResponseProto.di', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3548,
  serialized_end=3624,
)


_GETPREFERREDBLOCKSIZEREQUESTPROTO = _descriptor.Descriptor(
  name='GetPreferredBlockSizeRequestProto',
  full_name='hadoop.hdfs.GetPreferredBlockSizeRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='hadoop.hdfs.GetPreferredBlockSizeRequestProto.filename', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3626,
  serialized_end=3679,
)


_GETPREFERREDBLOCKSIZERESPONSEPROTO = _descriptor.Descriptor(
  name='GetPreferredBlockSizeResponseProto',
  full_name='hadoop.hdfs.GetPreferredBlockSizeResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bsize', full_name='hadoop.hdfs.GetPreferredBlockSizeResponseProto.bsize', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3681,
  serialized_end=3732,
)


_SETSAFEMODEREQUESTPROTO = _descriptor.Descriptor(
  name='SetSafeModeRequestProto',
  full_name='hadoop.hdfs.SetSafeModeRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='hadoop.hdfs.SetSafeModeRequestProto.action', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='checked', full_name='hadoop.hdfs.SetSafeModeRequestProto.checked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3734,
  serialized_end=3833,
)


_SETSAFEMODERESPONSEPROTO = _descriptor.Descriptor(
  name='SetSafeModeResponseProto',
  full_name='hadoop.hdfs.SetSafeModeResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.SetSafeModeResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3835,
  serialized_end=3877,
)


_SAVENAMESPACEREQUESTPROTO = _descriptor.Descriptor(
  name='SaveNamespaceRequestProto',
  full_name='hadoop.hdfs.SaveNamespaceRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3879,
  serialized_end=3906,
)


_SAVENAMESPACERESPONSEPROTO = _descriptor.Descriptor(
  name='SaveNamespaceResponseProto',
  full_name='hadoop.hdfs.SaveNamespaceResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3908,
  serialized_end=3936,
)


_ROLLEDITSREQUESTPROTO = _descriptor.Descriptor(
  name='RollEditsRequestProto',
  full_name='hadoop.hdfs.RollEditsRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3938,
  serialized_end=3961,
)


_ROLLEDITSRESPONSEPROTO = _descriptor.Descriptor(
  name='RollEditsResponseProto',
  full_name='hadoop.hdfs.RollEditsResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='newSegmentTxId', full_name='hadoop.hdfs.RollEditsResponseProto.newSegmentTxId', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3963,
  serialized_end=4011,
)


_RESTOREFAILEDSTORAGEREQUESTPROTO = _descriptor.Descriptor(
  name='RestoreFailedStorageRequestProto',
  full_name='hadoop.hdfs.RestoreFailedStorageRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='arg', full_name='hadoop.hdfs.RestoreFailedStorageRequestProto.arg', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4013,
  serialized_end=4060,
)


_RESTOREFAILEDSTORAGERESPONSEPROTO = _descriptor.Descriptor(
  name='RestoreFailedStorageResponseProto',
  full_name='hadoop.hdfs.RestoreFailedStorageResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.RestoreFailedStorageResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4062,
  serialized_end=4113,
)


_REFRESHNODESREQUESTPROTO = _descriptor.Descriptor(
  name='RefreshNodesRequestProto',
  full_name='hadoop.hdfs.RefreshNodesRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4115,
  serialized_end=4141,
)


_REFRESHNODESRESPONSEPROTO = _descriptor.Descriptor(
  name='RefreshNodesResponseProto',
  full_name='hadoop.hdfs.RefreshNodesResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4143,
  serialized_end=4170,
)


_FINALIZEUPGRADEREQUESTPROTO = _descriptor.Descriptor(
  name='FinalizeUpgradeRequestProto',
  full_name='hadoop.hdfs.FinalizeUpgradeRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4172,
  serialized_end=4201,
)


_FINALIZEUPGRADERESPONSEPROTO = _descriptor.Descriptor(
  name='FinalizeUpgradeResponseProto',
  full_name='hadoop.hdfs.FinalizeUpgradeResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4203,
  serialized_end=4233,
)


_LISTCORRUPTFILEBLOCKSREQUESTPROTO = _descriptor.Descriptor(
  name='ListCorruptFileBlocksRequestProto',
  full_name='hadoop.hdfs.ListCorruptFileBlocksRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='hadoop.hdfs.ListCorruptFileBlocksRequestProto.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='hadoop.hdfs.ListCorruptFileBlocksRequestProto.cookie', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4235,
  serialized_end=4300,
)


_LISTCORRUPTFILEBLOCKSRESPONSEPROTO = _descriptor.Descriptor(
  name='ListCorruptFileBlocksResponseProto',
  full_name='hadoop.hdfs.ListCorruptFileBlocksResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='corrupt', full_name='hadoop.hdfs.ListCorruptFileBlocksResponseProto.corrupt', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4302,
  serialized_end=4392,
)


_METASAVEREQUESTPROTO = _descriptor.Descriptor(
  name='MetaSaveRequestProto',
  full_name='hadoop.hdfs.MetaSaveRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='hadoop.hdfs.MetaSaveRequestProto.filename', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4394,
  serialized_end=4434,
)


_METASAVERESPONSEPROTO = _descriptor.Descriptor(
  name='MetaSaveResponseProto',
  full_name='hadoop.hdfs.MetaSaveResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4436,
  serialized_end=4459,
)


_GETFILEINFOREQUESTPROTO = _descriptor.Descriptor(
  name='GetFileInfoRequestProto',
  full_name='hadoop.hdfs.GetFileInfoRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.GetFileInfoRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4461,
  serialized_end=4499,
)


_GETFILEINFORESPONSEPROTO = _descriptor.Descriptor(
  name='GetFileInfoResponseProto',
  full_name='hadoop.hdfs.GetFileInfoResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fs', full_name='hadoop.hdfs.GetFileInfoResponseProto.fs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4501,
  serialized_end=4573,
)


_ISFILECLOSEDREQUESTPROTO = _descriptor.Descriptor(
  name='IsFileClosedRequestProto',
  full_name='hadoop.hdfs.IsFileClosedRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.IsFileClosedRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4575,
  serialized_end=4614,
)


_ISFILECLOSEDRESPONSEPROTO = _descriptor.Descriptor(
  name='IsFileClosedResponseProto',
  full_name='hadoop.hdfs.IsFileClosedResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='hadoop.hdfs.IsFileClosedResponseProto.result', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4616,
  serialized_end=4659,
)


_GETFILELINKINFOREQUESTPROTO = _descriptor.Descriptor(
  name='GetFileLinkInfoRequestProto',
  full_name='hadoop.hdfs.GetFileLinkInfoRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.GetFileLinkInfoRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4661,
  serialized_end=4703,
)


_GETFILELINKINFORESPONSEPROTO = _descriptor.Descriptor(
  name='GetFileLinkInfoResponseProto',
  full_name='hadoop.hdfs.GetFileLinkInfoResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fs', full_name='hadoop.hdfs.GetFileLinkInfoResponseProto.fs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4705,
  serialized_end=4781,
)


_GETCONTENTSUMMARYREQUESTPROTO = _descriptor.Descriptor(
  name='GetContentSummaryRequestProto',
  full_name='hadoop.hdfs.GetContentSummaryRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='hadoop.hdfs.GetContentSummaryRequestProto.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4783,
  serialized_end=4828,
)


_GETCONTENTSUMMARYRESPONSEPROTO = _descriptor.Descriptor(
  name='GetContentSummaryResponseProto',
  full_name='hadoop.hdfs.GetContentSummaryResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='hadoop.hdfs.GetContentSummaryResponseProto.summary', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4830,
  serialized_end=4913,
)


_SETQUOTAREQUESTPROTO = _descriptor.Descriptor(
  name='SetQuotaRequestProto',
  full_name='hadoop.hdfs.SetQuotaRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='hadoop.hdfs.SetQuotaRequestProto.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namespaceQuota', full_name='hadoop.hdfs.SetQuotaRequestProto.namespaceQuota', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='diskspaceQuota', full_name='hadoop.hdfs.SetQuotaRequestProto.diskspaceQuota', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4915,
  serialized_end=4999,
)


_SETQUOTARESPONSEPROTO = _descriptor.Descriptor(
  name='SetQuotaResponseProto',
  full_name='hadoop.hdfs.SetQuotaResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5001,
  serialized_end=5024,
)


_FSYNCREQUESTPROTO = _descriptor.Descriptor(
  name='FsyncRequestProto',
  full_name='hadoop.hdfs.FsyncRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.FsyncRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client', full_name='hadoop.hdfs.FsyncRequestProto.client', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastBlockLength', full_name='hadoop.hdfs.FsyncRequestProto.lastBlockLength', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5026,
  serialized_end=5103,
)


_FSYNCRESPONSEPROTO = _descriptor.Descriptor(
  name='FsyncResponseProto',
  full_name='hadoop.hdfs.FsyncResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5105,
  serialized_end=5125,
)


_SETTIMESREQUESTPROTO = _descriptor.Descriptor(
  name='SetTimesRequestProto',
  full_name='hadoop.hdfs.SetTimesRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='hadoop.hdfs.SetTimesRequestProto.src', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mtime', full_name='hadoop.hdfs.SetTimesRequestProto.mtime', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='atime', full_name='hadoop.hdfs.SetTimesRequestProto.atime', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5127,
  serialized_end=5192,
)


_SETTIMESRESPONSEPROTO = _descriptor.Descriptor(
  name='SetTimesResponseProto',
  full_name='hadoop.hdfs.SetTimesResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5194,
  serialized_end=5217,
)


_CREATESYMLINKREQUESTPROTO = _descriptor.Descriptor(
  name='CreateSymlinkRequestProto',
  full_name='hadoop.hdfs.CreateSymlinkRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='hadoop.hdfs.CreateSymlinkRequestProto.target', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='link', full_name='hadoop.hdfs.CreateSymlinkRequestProto.link', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dirPerm', full_name='hadoop.hdfs.CreateSymlinkRequestProto.dirPerm', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createParent', full_name='hadoop.hdfs.CreateSymlinkRequestProto.createParent', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5220,
  serialized_end=5348,
)


_CREATESYMLINKRESPONSEPROTO = _descriptor.Descriptor(
  name='CreateSymlinkResponseProto',
  full_name='hadoop.hdfs.CreateSymlinkResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5350,
  serialized_end=5378,
)


_GETLINKTARGETREQUESTPROTO = _descriptor.Descriptor(
  name='GetLinkTargetRequestProto',
  full_name='hadoop.hdfs.GetLinkTargetRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='hadoop.hdfs.GetLinkTargetRequestProto.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5380,
  serialized_end=5421,
)


_GETLINKTARGETRESPONSEPROTO = _descriptor.Descriptor(
  name='GetLinkTargetResponseProto',
  full_name='hadoop.hdfs.GetLinkTargetResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetPath', full_name='hadoop.hdfs.GetLinkTargetResponseProto.targetPath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5423,
  serialized_end=5471,
)


_UPDATEBLOCKFORPIPELINEREQUESTPROTO = _descriptor.Descriptor(
  name='UpdateBlockForPipelineRequestProto',
  full_name='hadoop.hdfs.UpdateBlockForPipelineRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.UpdateBlockForPipelineRequestProto.block', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.UpdateBlockForPipelineRequestProto.clientName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5473,
  serialized_end=5577,
)


_UPDATEBLOCKFORPIPELINERESPONSEPROTO = _descriptor.Descriptor(
  name='UpdateBlockForPipelineResponseProto',
  full_name='hadoop.hdfs.UpdateBlockForPipelineResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.UpdateBlockForPipelineResponseProto.block', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5579,
  serialized_end=5663,
)


_UPDATEPIPELINEREQUESTPROTO = _descriptor.Descriptor(
  name='UpdatePipelineRequestProto',
  full_name='hadoop.hdfs.UpdatePipelineRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientName', full_name='hadoop.hdfs.UpdatePipelineRequestProto.clientName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='oldBlock', full_name='hadoop.hdfs.UpdatePipelineRequestProto.oldBlock', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newBlock', full_name='hadoop.hdfs.UpdatePipelineRequestProto.newBlock', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newNodes', full_name='hadoop.hdfs.UpdatePipelineRequestProto.newNodes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5666,
  serialized_end=5864,
)


_UPDATEPIPELINERESPONSEPROTO = _descriptor.Descriptor(
  name='UpdatePipelineResponseProto',
  full_name='hadoop.hdfs.UpdatePipelineResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5866,
  serialized_end=5895,
)


_SETBALANCERBANDWIDTHREQUESTPROTO = _descriptor.Descriptor(
  name='SetBalancerBandwidthRequestProto',
  full_name='hadoop.hdfs.SetBalancerBandwidthRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bandwidth', full_name='hadoop.hdfs.SetBalancerBandwidthRequestProto.bandwidth', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5897,
  serialized_end=5950,
)


_SETBALANCERBANDWIDTHRESPONSEPROTO = _descriptor.Descriptor(
  name='SetBalancerBandwidthResponseProto',
  full_name='hadoop.hdfs.SetBalancerBandwidthResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5952,
  serialized_end=5987,
)


_GETDATAENCRYPTIONKEYREQUESTPROTO = _descriptor.Descriptor(
  name='GetDataEncryptionKeyRequestProto',
  full_name='hadoop.hdfs.GetDataEncryptionKeyRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5989,
  serialized_end=6023,
)


_GETDATAENCRYPTIONKEYRESPONSEPROTO = _descriptor.Descriptor(
  name='GetDataEncryptionKeyResponseProto',
  full_name='hadoop.hdfs.GetDataEncryptionKeyResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataEncryptionKey', full_name='hadoop.hdfs.GetDataEncryptionKeyResponseProto.dataEncryptionKey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6025,
  serialized_end=6124,
)


_CREATESNAPSHOTREQUESTPROTO = _descriptor.Descriptor(
  name='CreateSnapshotRequestProto',
  full_name='hadoop.hdfs.CreateSnapshotRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.CreateSnapshotRequestProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshotName', full_name='hadoop.hdfs.CreateSnapshotRequestProto.snapshotName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6126,
  serialized_end=6198,
)


_CREATESNAPSHOTRESPONSEPROTO = _descriptor.Descriptor(
  name='CreateSnapshotResponseProto',
  full_name='hadoop.hdfs.CreateSnapshotResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotPath', full_name='hadoop.hdfs.CreateSnapshotResponseProto.snapshotPath', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6200,
  serialized_end=6251,
)


_RENAMESNAPSHOTREQUESTPROTO = _descriptor.Descriptor(
  name='RenameSnapshotRequestProto',
  full_name='hadoop.hdfs.RenameSnapshotRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.RenameSnapshotRequestProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshotOldName', full_name='hadoop.hdfs.RenameSnapshotRequestProto.snapshotOldName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshotNewName', full_name='hadoop.hdfs.RenameSnapshotRequestProto.snapshotNewName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6253,
  serialized_end=6353,
)


_RENAMESNAPSHOTRESPONSEPROTO = _descriptor.Descriptor(
  name='RenameSnapshotResponseProto',
  full_name='hadoop.hdfs.RenameSnapshotResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6355,
  serialized_end=6384,
)


_ALLOWSNAPSHOTREQUESTPROTO = _descriptor.Descriptor(
  name='AllowSnapshotRequestProto',
  full_name='hadoop.hdfs.AllowSnapshotRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.AllowSnapshotRequestProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6386,
  serialized_end=6435,
)


_ALLOWSNAPSHOTRESPONSEPROTO = _descriptor.Descriptor(
  name='AllowSnapshotResponseProto',
  full_name='hadoop.hdfs.AllowSnapshotResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6437,
  serialized_end=6465,
)


_DISALLOWSNAPSHOTREQUESTPROTO = _descriptor.Descriptor(
  name='DisallowSnapshotRequestProto',
  full_name='hadoop.hdfs.DisallowSnapshotRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.DisallowSnapshotRequestProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6467,
  serialized_end=6519,
)


_DISALLOWSNAPSHOTRESPONSEPROTO = _descriptor.Descriptor(
  name='DisallowSnapshotResponseProto',
  full_name='hadoop.hdfs.DisallowSnapshotResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6521,
  serialized_end=6552,
)


_DELETESNAPSHOTREQUESTPROTO = _descriptor.Descriptor(
  name='DeleteSnapshotRequestProto',
  full_name='hadoop.hdfs.DeleteSnapshotRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.DeleteSnapshotRequestProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshotName', full_name='hadoop.hdfs.DeleteSnapshotRequestProto.snapshotName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6554,
  serialized_end=6626,
)


_DELETESNAPSHOTRESPONSEPROTO = _descriptor.Descriptor(
  name='DeleteSnapshotResponseProto',
  full_name='hadoop.hdfs.DeleteSnapshotResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6628,
  serialized_end=6657,
)

_GETBLOCKLOCATIONSRESPONSEPROTO.fields_by_name['locations'].message_type = hdfs__pb2._LOCATEDBLOCKSPROTO
_GETSERVERDEFAULTSRESPONSEPROTO.fields_by_name['serverDefaults'].message_type = hdfs__pb2._FSSERVERDEFAULTSPROTO
_CREATEREQUESTPROTO.fields_by_name['masked'].message_type = hdfs__pb2._FSPERMISSIONPROTO
_CREATERESPONSEPROTO.fields_by_name['fs'].message_type = hdfs__pb2._HDFSFILESTATUSPROTO
_APPENDRESPONSEPROTO.fields_by_name['block'].message_type = hdfs__pb2._LOCATEDBLOCKPROTO
_SETPERMISSIONREQUESTPROTO.fields_by_name['permission'].message_type = hdfs__pb2._FSPERMISSIONPROTO
_ABANDONBLOCKREQUESTPROTO.fields_by_name['b'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_ADDBLOCKREQUESTPROTO.fields_by_name['previous'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_ADDBLOCKREQUESTPROTO.fields_by_name['excludeNodes'].message_type = hdfs__pb2._DATANODEINFOPROTO
_ADDBLOCKRESPONSEPROTO.fields_by_name['block'].message_type = hdfs__pb2._LOCATEDBLOCKPROTO
_GETADDITIONALDATANODEREQUESTPROTO.fields_by_name['blk'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_GETADDITIONALDATANODEREQUESTPROTO.fields_by_name['existings'].message_type = hdfs__pb2._DATANODEINFOPROTO
_GETADDITIONALDATANODEREQUESTPROTO.fields_by_name['excludes'].message_type = hdfs__pb2._DATANODEINFOPROTO
_GETADDITIONALDATANODERESPONSEPROTO.fields_by_name['block'].message_type = hdfs__pb2._LOCATEDBLOCKPROTO
_COMPLETEREQUESTPROTO.fields_by_name['last'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_REPORTBADBLOCKSREQUESTPROTO.fields_by_name['blocks'].message_type = hdfs__pb2._LOCATEDBLOCKPROTO
_MKDIRSREQUESTPROTO.fields_by_name['masked'].message_type = hdfs__pb2._FSPERMISSIONPROTO
_GETLISTINGRESPONSEPROTO.fields_by_name['dirList'].message_type = hdfs__pb2._DIRECTORYLISTINGPROTO
_GETSNAPSHOTTABLEDIRLISTINGRESPONSEPROTO.fields_by_name['snapshottableDirList'].message_type = hdfs__pb2._SNAPSHOTTABLEDIRECTORYLISTINGPROTO
_GETSNAPSHOTDIFFREPORTRESPONSEPROTO.fields_by_name['diffReport'].message_type = hdfs__pb2._SNAPSHOTDIFFREPORTPROTO
_GETDATANODEREPORTREQUESTPROTO.fields_by_name['type'].enum_type = _DATANODEREPORTTYPEPROTO
_GETDATANODEREPORTRESPONSEPROTO.fields_by_name['di'].message_type = hdfs__pb2._DATANODEINFOPROTO
_SETSAFEMODEREQUESTPROTO.fields_by_name['action'].enum_type = _SAFEMODEACTIONPROTO
_LISTCORRUPTFILEBLOCKSRESPONSEPROTO.fields_by_name['corrupt'].message_type = hdfs__pb2._CORRUPTFILEBLOCKSPROTO
_GETFILEINFORESPONSEPROTO.fields_by_name['fs'].message_type = hdfs__pb2._HDFSFILESTATUSPROTO
_GETFILELINKINFORESPONSEPROTO.fields_by_name['fs'].message_type = hdfs__pb2._HDFSFILESTATUSPROTO
_GETCONTENTSUMMARYRESPONSEPROTO.fields_by_name['summary'].message_type = hdfs__pb2._CONTENTSUMMARYPROTO
_CREATESYMLINKREQUESTPROTO.fields_by_name['dirPerm'].message_type = hdfs__pb2._FSPERMISSIONPROTO
_UPDATEBLOCKFORPIPELINEREQUESTPROTO.fields_by_name['block'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_UPDATEBLOCKFORPIPELINERESPONSEPROTO.fields_by_name['block'].message_type = hdfs__pb2._LOCATEDBLOCKPROTO
_UPDATEPIPELINEREQUESTPROTO.fields_by_name['oldBlock'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_UPDATEPIPELINEREQUESTPROTO.fields_by_name['newBlock'].message_type = hdfs__pb2._EXTENDEDBLOCKPROTO
_UPDATEPIPELINEREQUESTPROTO.fields_by_name['newNodes'].message_type = hdfs__pb2._DATANODEIDPROTO
_GETDATAENCRYPTIONKEYRESPONSEPROTO.fields_by_name['dataEncryptionKey'].message_type = hdfs__pb2._DATAENCRYPTIONKEYPROTO
DESCRIPTOR.message_types_by_name['GetBlockLocationsRequestProto'] = _GETBLOCKLOCATIONSREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetBlockLocationsResponseProto'] = _GETBLOCKLOCATIONSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetServerDefaultsRequestProto'] = _GETSERVERDEFAULTSREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetServerDefaultsResponseProto'] = _GETSERVERDEFAULTSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['CreateRequestProto'] = _CREATEREQUESTPROTO
DESCRIPTOR.message_types_by_name['CreateResponseProto'] = _CREATERESPONSEPROTO
DESCRIPTOR.message_types_by_name['AppendRequestProto'] = _APPENDREQUESTPROTO
DESCRIPTOR.message_types_by_name['AppendResponseProto'] = _APPENDRESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetReplicationRequestProto'] = _SETREPLICATIONREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetReplicationResponseProto'] = _SETREPLICATIONRESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetPermissionRequestProto'] = _SETPERMISSIONREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetPermissionResponseProto'] = _SETPERMISSIONRESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetOwnerRequestProto'] = _SETOWNERREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetOwnerResponseProto'] = _SETOWNERRESPONSEPROTO
DESCRIPTOR.message_types_by_name['AbandonBlockRequestProto'] = _ABANDONBLOCKREQUESTPROTO
DESCRIPTOR.message_types_by_name['AbandonBlockResponseProto'] = _ABANDONBLOCKRESPONSEPROTO
DESCRIPTOR.message_types_by_name['AddBlockRequestProto'] = _ADDBLOCKREQUESTPROTO
DESCRIPTOR.message_types_by_name['AddBlockResponseProto'] = _ADDBLOCKRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetAdditionalDatanodeRequestProto'] = _GETADDITIONALDATANODEREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetAdditionalDatanodeResponseProto'] = _GETADDITIONALDATANODERESPONSEPROTO
DESCRIPTOR.message_types_by_name['CompleteRequestProto'] = _COMPLETEREQUESTPROTO
DESCRIPTOR.message_types_by_name['CompleteResponseProto'] = _COMPLETERESPONSEPROTO
DESCRIPTOR.message_types_by_name['ReportBadBlocksRequestProto'] = _REPORTBADBLOCKSREQUESTPROTO
DESCRIPTOR.message_types_by_name['ReportBadBlocksResponseProto'] = _REPORTBADBLOCKSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['ConcatRequestProto'] = _CONCATREQUESTPROTO
DESCRIPTOR.message_types_by_name['ConcatResponseProto'] = _CONCATRESPONSEPROTO
DESCRIPTOR.message_types_by_name['RenameRequestProto'] = _RENAMEREQUESTPROTO
DESCRIPTOR.message_types_by_name['RenameResponseProto'] = _RENAMERESPONSEPROTO
DESCRIPTOR.message_types_by_name['Rename2RequestProto'] = _RENAME2REQUESTPROTO
DESCRIPTOR.message_types_by_name['Rename2ResponseProto'] = _RENAME2RESPONSEPROTO
DESCRIPTOR.message_types_by_name['DeleteRequestProto'] = _DELETEREQUESTPROTO
DESCRIPTOR.message_types_by_name['DeleteResponseProto'] = _DELETERESPONSEPROTO
DESCRIPTOR.message_types_by_name['MkdirsRequestProto'] = _MKDIRSREQUESTPROTO
DESCRIPTOR.message_types_by_name['MkdirsResponseProto'] = _MKDIRSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetListingRequestProto'] = _GETLISTINGREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetListingResponseProto'] = _GETLISTINGRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetSnapshottableDirListingRequestProto'] = _GETSNAPSHOTTABLEDIRLISTINGREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetSnapshottableDirListingResponseProto'] = _GETSNAPSHOTTABLEDIRLISTINGRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetSnapshotDiffReportRequestProto'] = _GETSNAPSHOTDIFFREPORTREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetSnapshotDiffReportResponseProto'] = _GETSNAPSHOTDIFFREPORTRESPONSEPROTO
DESCRIPTOR.message_types_by_name['RenewLeaseRequestProto'] = _RENEWLEASEREQUESTPROTO
DESCRIPTOR.message_types_by_name['RenewLeaseResponseProto'] = _RENEWLEASERESPONSEPROTO
DESCRIPTOR.message_types_by_name['RecoverLeaseRequestProto'] = _RECOVERLEASEREQUESTPROTO
DESCRIPTOR.message_types_by_name['RecoverLeaseResponseProto'] = _RECOVERLEASERESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetFsStatusRequestProto'] = _GETFSSTATUSREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetFsStatsResponseProto'] = _GETFSSTATSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetDatanodeReportRequestProto'] = _GETDATANODEREPORTREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetDatanodeReportResponseProto'] = _GETDATANODEREPORTRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetPreferredBlockSizeRequestProto'] = _GETPREFERREDBLOCKSIZEREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetPreferredBlockSizeResponseProto'] = _GETPREFERREDBLOCKSIZERESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetSafeModeRequestProto'] = _SETSAFEMODEREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetSafeModeResponseProto'] = _SETSAFEMODERESPONSEPROTO
DESCRIPTOR.message_types_by_name['SaveNamespaceRequestProto'] = _SAVENAMESPACEREQUESTPROTO
DESCRIPTOR.message_types_by_name['SaveNamespaceResponseProto'] = _SAVENAMESPACERESPONSEPROTO
DESCRIPTOR.message_types_by_name['RollEditsRequestProto'] = _ROLLEDITSREQUESTPROTO
DESCRIPTOR.message_types_by_name['RollEditsResponseProto'] = _ROLLEDITSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['RestoreFailedStorageRequestProto'] = _RESTOREFAILEDSTORAGEREQUESTPROTO
DESCRIPTOR.message_types_by_name['RestoreFailedStorageResponseProto'] = _RESTOREFAILEDSTORAGERESPONSEPROTO
DESCRIPTOR.message_types_by_name['RefreshNodesRequestProto'] = _REFRESHNODESREQUESTPROTO
DESCRIPTOR.message_types_by_name['RefreshNodesResponseProto'] = _REFRESHNODESRESPONSEPROTO
DESCRIPTOR.message_types_by_name['FinalizeUpgradeRequestProto'] = _FINALIZEUPGRADEREQUESTPROTO
DESCRIPTOR.message_types_by_name['FinalizeUpgradeResponseProto'] = _FINALIZEUPGRADERESPONSEPROTO
DESCRIPTOR.message_types_by_name['ListCorruptFileBlocksRequestProto'] = _LISTCORRUPTFILEBLOCKSREQUESTPROTO
DESCRIPTOR.message_types_by_name['ListCorruptFileBlocksResponseProto'] = _LISTCORRUPTFILEBLOCKSRESPONSEPROTO
DESCRIPTOR.message_types_by_name['MetaSaveRequestProto'] = _METASAVEREQUESTPROTO
DESCRIPTOR.message_types_by_name['MetaSaveResponseProto'] = _METASAVERESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetFileInfoRequestProto'] = _GETFILEINFOREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetFileInfoResponseProto'] = _GETFILEINFORESPONSEPROTO
DESCRIPTOR.message_types_by_name['IsFileClosedRequestProto'] = _ISFILECLOSEDREQUESTPROTO
DESCRIPTOR.message_types_by_name['IsFileClosedResponseProto'] = _ISFILECLOSEDRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetFileLinkInfoRequestProto'] = _GETFILELINKINFOREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetFileLinkInfoResponseProto'] = _GETFILELINKINFORESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetContentSummaryRequestProto'] = _GETCONTENTSUMMARYREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetContentSummaryResponseProto'] = _GETCONTENTSUMMARYRESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetQuotaRequestProto'] = _SETQUOTAREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetQuotaResponseProto'] = _SETQUOTARESPONSEPROTO
DESCRIPTOR.message_types_by_name['FsyncRequestProto'] = _FSYNCREQUESTPROTO
DESCRIPTOR.message_types_by_name['FsyncResponseProto'] = _FSYNCRESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetTimesRequestProto'] = _SETTIMESREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetTimesResponseProto'] = _SETTIMESRESPONSEPROTO
DESCRIPTOR.message_types_by_name['CreateSymlinkRequestProto'] = _CREATESYMLINKREQUESTPROTO
DESCRIPTOR.message_types_by_name['CreateSymlinkResponseProto'] = _CREATESYMLINKRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetLinkTargetRequestProto'] = _GETLINKTARGETREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetLinkTargetResponseProto'] = _GETLINKTARGETRESPONSEPROTO
DESCRIPTOR.message_types_by_name['UpdateBlockForPipelineRequestProto'] = _UPDATEBLOCKFORPIPELINEREQUESTPROTO
DESCRIPTOR.message_types_by_name['UpdateBlockForPipelineResponseProto'] = _UPDATEBLOCKFORPIPELINERESPONSEPROTO
DESCRIPTOR.message_types_by_name['UpdatePipelineRequestProto'] = _UPDATEPIPELINEREQUESTPROTO
DESCRIPTOR.message_types_by_name['UpdatePipelineResponseProto'] = _UPDATEPIPELINERESPONSEPROTO
DESCRIPTOR.message_types_by_name['SetBalancerBandwidthRequestProto'] = _SETBALANCERBANDWIDTHREQUESTPROTO
DESCRIPTOR.message_types_by_name['SetBalancerBandwidthResponseProto'] = _SETBALANCERBANDWIDTHRESPONSEPROTO
DESCRIPTOR.message_types_by_name['GetDataEncryptionKeyRequestProto'] = _GETDATAENCRYPTIONKEYREQUESTPROTO
DESCRIPTOR.message_types_by_name['GetDataEncryptionKeyResponseProto'] = _GETDATAENCRYPTIONKEYRESPONSEPROTO
DESCRIPTOR.message_types_by_name['CreateSnapshotRequestProto'] = _CREATESNAPSHOTREQUESTPROTO
DESCRIPTOR.message_types_by_name['CreateSnapshotResponseProto'] = _CREATESNAPSHOTRESPONSEPROTO
DESCRIPTOR.message_types_by_name['RenameSnapshotRequestProto'] = _RENAMESNAPSHOTREQUESTPROTO
DESCRIPTOR.message_types_by_name['RenameSnapshotResponseProto'] = _RENAMESNAPSHOTRESPONSEPROTO
DESCRIPTOR.message_types_by_name['AllowSnapshotRequestProto'] = _ALLOWSNAPSHOTREQUESTPROTO
DESCRIPTOR.message_types_by_name['AllowSnapshotResponseProto'] = _ALLOWSNAPSHOTRESPONSEPROTO
DESCRIPTOR.message_types_by_name['DisallowSnapshotRequestProto'] = _DISALLOWSNAPSHOTREQUESTPROTO
DESCRIPTOR.message_types_by_name['DisallowSnapshotResponseProto'] = _DISALLOWSNAPSHOTRESPONSEPROTO
DESCRIPTOR.message_types_by_name['DeleteSnapshotRequestProto'] = _DELETESNAPSHOTREQUESTPROTO
DESCRIPTOR.message_types_by_name['DeleteSnapshotResponseProto'] = _DELETESNAPSHOTRESPONSEPROTO
DESCRIPTOR.enum_types_by_name['CreateFlagProto'] = _CREATEFLAGPROTO
DESCRIPTOR.enum_types_by_name['DatanodeReportTypeProto'] = _DATANODEREPORTTYPEPROTO
DESCRIPTOR.enum_types_by_name['SafeModeActionProto'] = _SAFEMODEACTIONPROTO

GetBlockLocationsRequestProto = _reflection.GeneratedProtocolMessageType('GetBlockLocationsRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETBLOCKLOCATIONSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetBlockLocationsRequestProto)
  ))
_sym_db.RegisterMessage(GetBlockLocationsRequestProto)

GetBlockLocationsResponseProto = _reflection.GeneratedProtocolMessageType('GetBlockLocationsResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETBLOCKLOCATIONSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetBlockLocationsResponseProto)
  ))
_sym_db.RegisterMessage(GetBlockLocationsResponseProto)

GetServerDefaultsRequestProto = _reflection.GeneratedProtocolMessageType('GetServerDefaultsRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETSERVERDEFAULTSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetServerDefaultsRequestProto)
  ))
_sym_db.RegisterMessage(GetServerDefaultsRequestProto)

GetServerDefaultsResponseProto = _reflection.GeneratedProtocolMessageType('GetServerDefaultsResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETSERVERDEFAULTSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetServerDefaultsResponseProto)
  ))
_sym_db.RegisterMessage(GetServerDefaultsResponseProto)

CreateRequestProto = _reflection.GeneratedProtocolMessageType('CreateRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CreateRequestProto)
  ))
_sym_db.RegisterMessage(CreateRequestProto)

CreateResponseProto = _reflection.GeneratedProtocolMessageType('CreateResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _CREATERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CreateResponseProto)
  ))
_sym_db.RegisterMessage(CreateResponseProto)

AppendRequestProto = _reflection.GeneratedProtocolMessageType('AppendRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _APPENDREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AppendRequestProto)
  ))
_sym_db.RegisterMessage(AppendRequestProto)

AppendResponseProto = _reflection.GeneratedProtocolMessageType('AppendResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _APPENDRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AppendResponseProto)
  ))
_sym_db.RegisterMessage(AppendResponseProto)

SetReplicationRequestProto = _reflection.GeneratedProtocolMessageType('SetReplicationRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETREPLICATIONREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetReplicationRequestProto)
  ))
_sym_db.RegisterMessage(SetReplicationRequestProto)

SetReplicationResponseProto = _reflection.GeneratedProtocolMessageType('SetReplicationResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETREPLICATIONRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetReplicationResponseProto)
  ))
_sym_db.RegisterMessage(SetReplicationResponseProto)

SetPermissionRequestProto = _reflection.GeneratedProtocolMessageType('SetPermissionRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETPERMISSIONREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetPermissionRequestProto)
  ))
_sym_db.RegisterMessage(SetPermissionRequestProto)

SetPermissionResponseProto = _reflection.GeneratedProtocolMessageType('SetPermissionResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETPERMISSIONRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetPermissionResponseProto)
  ))
_sym_db.RegisterMessage(SetPermissionResponseProto)

SetOwnerRequestProto = _reflection.GeneratedProtocolMessageType('SetOwnerRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETOWNERREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetOwnerRequestProto)
  ))
_sym_db.RegisterMessage(SetOwnerRequestProto)

SetOwnerResponseProto = _reflection.GeneratedProtocolMessageType('SetOwnerResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETOWNERRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetOwnerResponseProto)
  ))
_sym_db.RegisterMessage(SetOwnerResponseProto)

AbandonBlockRequestProto = _reflection.GeneratedProtocolMessageType('AbandonBlockRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _ABANDONBLOCKREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AbandonBlockRequestProto)
  ))
_sym_db.RegisterMessage(AbandonBlockRequestProto)

AbandonBlockResponseProto = _reflection.GeneratedProtocolMessageType('AbandonBlockResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _ABANDONBLOCKRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AbandonBlockResponseProto)
  ))
_sym_db.RegisterMessage(AbandonBlockResponseProto)

AddBlockRequestProto = _reflection.GeneratedProtocolMessageType('AddBlockRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _ADDBLOCKREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AddBlockRequestProto)
  ))
_sym_db.RegisterMessage(AddBlockRequestProto)

AddBlockResponseProto = _reflection.GeneratedProtocolMessageType('AddBlockResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _ADDBLOCKRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AddBlockResponseProto)
  ))
_sym_db.RegisterMessage(AddBlockResponseProto)

GetAdditionalDatanodeRequestProto = _reflection.GeneratedProtocolMessageType('GetAdditionalDatanodeRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETADDITIONALDATANODEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetAdditionalDatanodeRequestProto)
  ))
_sym_db.RegisterMessage(GetAdditionalDatanodeRequestProto)

GetAdditionalDatanodeResponseProto = _reflection.GeneratedProtocolMessageType('GetAdditionalDatanodeResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETADDITIONALDATANODERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetAdditionalDatanodeResponseProto)
  ))
_sym_db.RegisterMessage(GetAdditionalDatanodeResponseProto)

CompleteRequestProto = _reflection.GeneratedProtocolMessageType('CompleteRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _COMPLETEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CompleteRequestProto)
  ))
_sym_db.RegisterMessage(CompleteRequestProto)

CompleteResponseProto = _reflection.GeneratedProtocolMessageType('CompleteResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _COMPLETERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CompleteResponseProto)
  ))
_sym_db.RegisterMessage(CompleteResponseProto)

ReportBadBlocksRequestProto = _reflection.GeneratedProtocolMessageType('ReportBadBlocksRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _REPORTBADBLOCKSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ReportBadBlocksRequestProto)
  ))
_sym_db.RegisterMessage(ReportBadBlocksRequestProto)

ReportBadBlocksResponseProto = _reflection.GeneratedProtocolMessageType('ReportBadBlocksResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _REPORTBADBLOCKSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ReportBadBlocksResponseProto)
  ))
_sym_db.RegisterMessage(ReportBadBlocksResponseProto)

ConcatRequestProto = _reflection.GeneratedProtocolMessageType('ConcatRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _CONCATREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ConcatRequestProto)
  ))
_sym_db.RegisterMessage(ConcatRequestProto)

ConcatResponseProto = _reflection.GeneratedProtocolMessageType('ConcatResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _CONCATRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ConcatResponseProto)
  ))
_sym_db.RegisterMessage(ConcatResponseProto)

RenameRequestProto = _reflection.GeneratedProtocolMessageType('RenameRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RENAMEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RenameRequestProto)
  ))
_sym_db.RegisterMessage(RenameRequestProto)

RenameResponseProto = _reflection.GeneratedProtocolMessageType('RenameResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RENAMERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RenameResponseProto)
  ))
_sym_db.RegisterMessage(RenameResponseProto)

Rename2RequestProto = _reflection.GeneratedProtocolMessageType('Rename2RequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RENAME2REQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.Rename2RequestProto)
  ))
_sym_db.RegisterMessage(Rename2RequestProto)

Rename2ResponseProto = _reflection.GeneratedProtocolMessageType('Rename2ResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RENAME2RESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.Rename2ResponseProto)
  ))
_sym_db.RegisterMessage(Rename2ResponseProto)

DeleteRequestProto = _reflection.GeneratedProtocolMessageType('DeleteRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DeleteRequestProto)
  ))
_sym_db.RegisterMessage(DeleteRequestProto)

DeleteResponseProto = _reflection.GeneratedProtocolMessageType('DeleteResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DeleteResponseProto)
  ))
_sym_db.RegisterMessage(DeleteResponseProto)

MkdirsRequestProto = _reflection.GeneratedProtocolMessageType('MkdirsRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _MKDIRSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.MkdirsRequestProto)
  ))
_sym_db.RegisterMessage(MkdirsRequestProto)

MkdirsResponseProto = _reflection.GeneratedProtocolMessageType('MkdirsResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _MKDIRSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.MkdirsResponseProto)
  ))
_sym_db.RegisterMessage(MkdirsResponseProto)

GetListingRequestProto = _reflection.GeneratedProtocolMessageType('GetListingRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTINGREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetListingRequestProto)
  ))
_sym_db.RegisterMessage(GetListingRequestProto)

GetListingResponseProto = _reflection.GeneratedProtocolMessageType('GetListingResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTINGRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetListingResponseProto)
  ))
_sym_db.RegisterMessage(GetListingResponseProto)

GetSnapshottableDirListingRequestProto = _reflection.GeneratedProtocolMessageType('GetSnapshottableDirListingRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETSNAPSHOTTABLEDIRLISTINGREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetSnapshottableDirListingRequestProto)
  ))
_sym_db.RegisterMessage(GetSnapshottableDirListingRequestProto)

GetSnapshottableDirListingResponseProto = _reflection.GeneratedProtocolMessageType('GetSnapshottableDirListingResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETSNAPSHOTTABLEDIRLISTINGRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetSnapshottableDirListingResponseProto)
  ))
_sym_db.RegisterMessage(GetSnapshottableDirListingResponseProto)

GetSnapshotDiffReportRequestProto = _reflection.GeneratedProtocolMessageType('GetSnapshotDiffReportRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETSNAPSHOTDIFFREPORTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetSnapshotDiffReportRequestProto)
  ))
_sym_db.RegisterMessage(GetSnapshotDiffReportRequestProto)

GetSnapshotDiffReportResponseProto = _reflection.GeneratedProtocolMessageType('GetSnapshotDiffReportResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETSNAPSHOTDIFFREPORTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetSnapshotDiffReportResponseProto)
  ))
_sym_db.RegisterMessage(GetSnapshotDiffReportResponseProto)

RenewLeaseRequestProto = _reflection.GeneratedProtocolMessageType('RenewLeaseRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RENEWLEASEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RenewLeaseRequestProto)
  ))
_sym_db.RegisterMessage(RenewLeaseRequestProto)

RenewLeaseResponseProto = _reflection.GeneratedProtocolMessageType('RenewLeaseResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RENEWLEASERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RenewLeaseResponseProto)
  ))
_sym_db.RegisterMessage(RenewLeaseResponseProto)

RecoverLeaseRequestProto = _reflection.GeneratedProtocolMessageType('RecoverLeaseRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RECOVERLEASEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RecoverLeaseRequestProto)
  ))
_sym_db.RegisterMessage(RecoverLeaseRequestProto)

RecoverLeaseResponseProto = _reflection.GeneratedProtocolMessageType('RecoverLeaseResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RECOVERLEASERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RecoverLeaseResponseProto)
  ))
_sym_db.RegisterMessage(RecoverLeaseResponseProto)

GetFsStatusRequestProto = _reflection.GeneratedProtocolMessageType('GetFsStatusRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETFSSTATUSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetFsStatusRequestProto)
  ))
_sym_db.RegisterMessage(GetFsStatusRequestProto)

GetFsStatsResponseProto = _reflection.GeneratedProtocolMessageType('GetFsStatsResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETFSSTATSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetFsStatsResponseProto)
  ))
_sym_db.RegisterMessage(GetFsStatsResponseProto)

GetDatanodeReportRequestProto = _reflection.GeneratedProtocolMessageType('GetDatanodeReportRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETDATANODEREPORTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetDatanodeReportRequestProto)
  ))
_sym_db.RegisterMessage(GetDatanodeReportRequestProto)

GetDatanodeReportResponseProto = _reflection.GeneratedProtocolMessageType('GetDatanodeReportResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETDATANODEREPORTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetDatanodeReportResponseProto)
  ))
_sym_db.RegisterMessage(GetDatanodeReportResponseProto)

GetPreferredBlockSizeRequestProto = _reflection.GeneratedProtocolMessageType('GetPreferredBlockSizeRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETPREFERREDBLOCKSIZEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetPreferredBlockSizeRequestProto)
  ))
_sym_db.RegisterMessage(GetPreferredBlockSizeRequestProto)

GetPreferredBlockSizeResponseProto = _reflection.GeneratedProtocolMessageType('GetPreferredBlockSizeResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETPREFERREDBLOCKSIZERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetPreferredBlockSizeResponseProto)
  ))
_sym_db.RegisterMessage(GetPreferredBlockSizeResponseProto)

SetSafeModeRequestProto = _reflection.GeneratedProtocolMessageType('SetSafeModeRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETSAFEMODEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetSafeModeRequestProto)
  ))
_sym_db.RegisterMessage(SetSafeModeRequestProto)

SetSafeModeResponseProto = _reflection.GeneratedProtocolMessageType('SetSafeModeResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETSAFEMODERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetSafeModeResponseProto)
  ))
_sym_db.RegisterMessage(SetSafeModeResponseProto)

SaveNamespaceRequestProto = _reflection.GeneratedProtocolMessageType('SaveNamespaceRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SAVENAMESPACEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SaveNamespaceRequestProto)
  ))
_sym_db.RegisterMessage(SaveNamespaceRequestProto)

SaveNamespaceResponseProto = _reflection.GeneratedProtocolMessageType('SaveNamespaceResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SAVENAMESPACERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SaveNamespaceResponseProto)
  ))
_sym_db.RegisterMessage(SaveNamespaceResponseProto)

RollEditsRequestProto = _reflection.GeneratedProtocolMessageType('RollEditsRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _ROLLEDITSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RollEditsRequestProto)
  ))
_sym_db.RegisterMessage(RollEditsRequestProto)

RollEditsResponseProto = _reflection.GeneratedProtocolMessageType('RollEditsResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _ROLLEDITSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RollEditsResponseProto)
  ))
_sym_db.RegisterMessage(RollEditsResponseProto)

RestoreFailedStorageRequestProto = _reflection.GeneratedProtocolMessageType('RestoreFailedStorageRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RESTOREFAILEDSTORAGEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RestoreFailedStorageRequestProto)
  ))
_sym_db.RegisterMessage(RestoreFailedStorageRequestProto)

RestoreFailedStorageResponseProto = _reflection.GeneratedProtocolMessageType('RestoreFailedStorageResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RESTOREFAILEDSTORAGERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RestoreFailedStorageResponseProto)
  ))
_sym_db.RegisterMessage(RestoreFailedStorageResponseProto)

RefreshNodesRequestProto = _reflection.GeneratedProtocolMessageType('RefreshNodesRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _REFRESHNODESREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RefreshNodesRequestProto)
  ))
_sym_db.RegisterMessage(RefreshNodesRequestProto)

RefreshNodesResponseProto = _reflection.GeneratedProtocolMessageType('RefreshNodesResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _REFRESHNODESRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RefreshNodesResponseProto)
  ))
_sym_db.RegisterMessage(RefreshNodesResponseProto)

FinalizeUpgradeRequestProto = _reflection.GeneratedProtocolMessageType('FinalizeUpgradeRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _FINALIZEUPGRADEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.FinalizeUpgradeRequestProto)
  ))
_sym_db.RegisterMessage(FinalizeUpgradeRequestProto)

FinalizeUpgradeResponseProto = _reflection.GeneratedProtocolMessageType('FinalizeUpgradeResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _FINALIZEUPGRADERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.FinalizeUpgradeResponseProto)
  ))
_sym_db.RegisterMessage(FinalizeUpgradeResponseProto)

ListCorruptFileBlocksRequestProto = _reflection.GeneratedProtocolMessageType('ListCorruptFileBlocksRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _LISTCORRUPTFILEBLOCKSREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ListCorruptFileBlocksRequestProto)
  ))
_sym_db.RegisterMessage(ListCorruptFileBlocksRequestProto)

ListCorruptFileBlocksResponseProto = _reflection.GeneratedProtocolMessageType('ListCorruptFileBlocksResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _LISTCORRUPTFILEBLOCKSRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ListCorruptFileBlocksResponseProto)
  ))
_sym_db.RegisterMessage(ListCorruptFileBlocksResponseProto)

MetaSaveRequestProto = _reflection.GeneratedProtocolMessageType('MetaSaveRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _METASAVEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.MetaSaveRequestProto)
  ))
_sym_db.RegisterMessage(MetaSaveRequestProto)

MetaSaveResponseProto = _reflection.GeneratedProtocolMessageType('MetaSaveResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _METASAVERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.MetaSaveResponseProto)
  ))
_sym_db.RegisterMessage(MetaSaveResponseProto)

GetFileInfoRequestProto = _reflection.GeneratedProtocolMessageType('GetFileInfoRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETFILEINFOREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetFileInfoRequestProto)
  ))
_sym_db.RegisterMessage(GetFileInfoRequestProto)

GetFileInfoResponseProto = _reflection.GeneratedProtocolMessageType('GetFileInfoResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETFILEINFORESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetFileInfoResponseProto)
  ))
_sym_db.RegisterMessage(GetFileInfoResponseProto)

IsFileClosedRequestProto = _reflection.GeneratedProtocolMessageType('IsFileClosedRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _ISFILECLOSEDREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.IsFileClosedRequestProto)
  ))
_sym_db.RegisterMessage(IsFileClosedRequestProto)

IsFileClosedResponseProto = _reflection.GeneratedProtocolMessageType('IsFileClosedResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _ISFILECLOSEDRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.IsFileClosedResponseProto)
  ))
_sym_db.RegisterMessage(IsFileClosedResponseProto)

GetFileLinkInfoRequestProto = _reflection.GeneratedProtocolMessageType('GetFileLinkInfoRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETFILELINKINFOREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetFileLinkInfoRequestProto)
  ))
_sym_db.RegisterMessage(GetFileLinkInfoRequestProto)

GetFileLinkInfoResponseProto = _reflection.GeneratedProtocolMessageType('GetFileLinkInfoResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETFILELINKINFORESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetFileLinkInfoResponseProto)
  ))
_sym_db.RegisterMessage(GetFileLinkInfoResponseProto)

GetContentSummaryRequestProto = _reflection.GeneratedProtocolMessageType('GetContentSummaryRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETCONTENTSUMMARYREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetContentSummaryRequestProto)
  ))
_sym_db.RegisterMessage(GetContentSummaryRequestProto)

GetContentSummaryResponseProto = _reflection.GeneratedProtocolMessageType('GetContentSummaryResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETCONTENTSUMMARYRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetContentSummaryResponseProto)
  ))
_sym_db.RegisterMessage(GetContentSummaryResponseProto)

SetQuotaRequestProto = _reflection.GeneratedProtocolMessageType('SetQuotaRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETQUOTAREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetQuotaRequestProto)
  ))
_sym_db.RegisterMessage(SetQuotaRequestProto)

SetQuotaResponseProto = _reflection.GeneratedProtocolMessageType('SetQuotaResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETQUOTARESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetQuotaResponseProto)
  ))
_sym_db.RegisterMessage(SetQuotaResponseProto)

FsyncRequestProto = _reflection.GeneratedProtocolMessageType('FsyncRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _FSYNCREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.FsyncRequestProto)
  ))
_sym_db.RegisterMessage(FsyncRequestProto)

FsyncResponseProto = _reflection.GeneratedProtocolMessageType('FsyncResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _FSYNCRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.FsyncResponseProto)
  ))
_sym_db.RegisterMessage(FsyncResponseProto)

SetTimesRequestProto = _reflection.GeneratedProtocolMessageType('SetTimesRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETTIMESREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetTimesRequestProto)
  ))
_sym_db.RegisterMessage(SetTimesRequestProto)

SetTimesResponseProto = _reflection.GeneratedProtocolMessageType('SetTimesResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETTIMESRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetTimesResponseProto)
  ))
_sym_db.RegisterMessage(SetTimesResponseProto)

CreateSymlinkRequestProto = _reflection.GeneratedProtocolMessageType('CreateSymlinkRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _CREATESYMLINKREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CreateSymlinkRequestProto)
  ))
_sym_db.RegisterMessage(CreateSymlinkRequestProto)

CreateSymlinkResponseProto = _reflection.GeneratedProtocolMessageType('CreateSymlinkResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _CREATESYMLINKRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CreateSymlinkResponseProto)
  ))
_sym_db.RegisterMessage(CreateSymlinkResponseProto)

GetLinkTargetRequestProto = _reflection.GeneratedProtocolMessageType('GetLinkTargetRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETLINKTARGETREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetLinkTargetRequestProto)
  ))
_sym_db.RegisterMessage(GetLinkTargetRequestProto)

GetLinkTargetResponseProto = _reflection.GeneratedProtocolMessageType('GetLinkTargetResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETLINKTARGETRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetLinkTargetResponseProto)
  ))
_sym_db.RegisterMessage(GetLinkTargetResponseProto)

UpdateBlockForPipelineRequestProto = _reflection.GeneratedProtocolMessageType('UpdateBlockForPipelineRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEBLOCKFORPIPELINEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.UpdateBlockForPipelineRequestProto)
  ))
_sym_db.RegisterMessage(UpdateBlockForPipelineRequestProto)

UpdateBlockForPipelineResponseProto = _reflection.GeneratedProtocolMessageType('UpdateBlockForPipelineResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEBLOCKFORPIPELINERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.UpdateBlockForPipelineResponseProto)
  ))
_sym_db.RegisterMessage(UpdateBlockForPipelineResponseProto)

UpdatePipelineRequestProto = _reflection.GeneratedProtocolMessageType('UpdatePipelineRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPIPELINEREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.UpdatePipelineRequestProto)
  ))
_sym_db.RegisterMessage(UpdatePipelineRequestProto)

UpdatePipelineResponseProto = _reflection.GeneratedProtocolMessageType('UpdatePipelineResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPIPELINERESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.UpdatePipelineResponseProto)
  ))
_sym_db.RegisterMessage(UpdatePipelineResponseProto)

SetBalancerBandwidthRequestProto = _reflection.GeneratedProtocolMessageType('SetBalancerBandwidthRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _SETBALANCERBANDWIDTHREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetBalancerBandwidthRequestProto)
  ))
_sym_db.RegisterMessage(SetBalancerBandwidthRequestProto)

SetBalancerBandwidthResponseProto = _reflection.GeneratedProtocolMessageType('SetBalancerBandwidthResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _SETBALANCERBANDWIDTHRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SetBalancerBandwidthResponseProto)
  ))
_sym_db.RegisterMessage(SetBalancerBandwidthResponseProto)

GetDataEncryptionKeyRequestProto = _reflection.GeneratedProtocolMessageType('GetDataEncryptionKeyRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _GETDATAENCRYPTIONKEYREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetDataEncryptionKeyRequestProto)
  ))
_sym_db.RegisterMessage(GetDataEncryptionKeyRequestProto)

GetDataEncryptionKeyResponseProto = _reflection.GeneratedProtocolMessageType('GetDataEncryptionKeyResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _GETDATAENCRYPTIONKEYRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.GetDataEncryptionKeyResponseProto)
  ))
_sym_db.RegisterMessage(GetDataEncryptionKeyResponseProto)

CreateSnapshotRequestProto = _reflection.GeneratedProtocolMessageType('CreateSnapshotRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _CREATESNAPSHOTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CreateSnapshotRequestProto)
  ))
_sym_db.RegisterMessage(CreateSnapshotRequestProto)

CreateSnapshotResponseProto = _reflection.GeneratedProtocolMessageType('CreateSnapshotResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _CREATESNAPSHOTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CreateSnapshotResponseProto)
  ))
_sym_db.RegisterMessage(CreateSnapshotResponseProto)

RenameSnapshotRequestProto = _reflection.GeneratedProtocolMessageType('RenameSnapshotRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _RENAMESNAPSHOTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RenameSnapshotRequestProto)
  ))
_sym_db.RegisterMessage(RenameSnapshotRequestProto)

RenameSnapshotResponseProto = _reflection.GeneratedProtocolMessageType('RenameSnapshotResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _RENAMESNAPSHOTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RenameSnapshotResponseProto)
  ))
_sym_db.RegisterMessage(RenameSnapshotResponseProto)

AllowSnapshotRequestProto = _reflection.GeneratedProtocolMessageType('AllowSnapshotRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _ALLOWSNAPSHOTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AllowSnapshotRequestProto)
  ))
_sym_db.RegisterMessage(AllowSnapshotRequestProto)

AllowSnapshotResponseProto = _reflection.GeneratedProtocolMessageType('AllowSnapshotResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _ALLOWSNAPSHOTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.AllowSnapshotResponseProto)
  ))
_sym_db.RegisterMessage(AllowSnapshotResponseProto)

DisallowSnapshotRequestProto = _reflection.GeneratedProtocolMessageType('DisallowSnapshotRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _DISALLOWSNAPSHOTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DisallowSnapshotRequestProto)
  ))
_sym_db.RegisterMessage(DisallowSnapshotRequestProto)

DisallowSnapshotResponseProto = _reflection.GeneratedProtocolMessageType('DisallowSnapshotResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _DISALLOWSNAPSHOTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DisallowSnapshotResponseProto)
  ))
_sym_db.RegisterMessage(DisallowSnapshotResponseProto)

DeleteSnapshotRequestProto = _reflection.GeneratedProtocolMessageType('DeleteSnapshotRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _DELETESNAPSHOTREQUESTPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DeleteSnapshotRequestProto)
  ))
_sym_db.RegisterMessage(DeleteSnapshotRequestProto)

DeleteSnapshotResponseProto = _reflection.GeneratedProtocolMessageType('DeleteSnapshotResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _DELETESNAPSHOTRESPONSEPROTO,
  __module__ = 'ClientNamenodeProtocol_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DeleteSnapshotResponseProto)
  ))
_sym_db.RegisterMessage(DeleteSnapshotResponseProto)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%org.apache.hadoop.hdfs.protocol.protoB\034ClientNamenodeProtocolProtos\210\001\001\220\001\001\240\001\001'))

_CLIENTNAMENODEPROTOCOL = _descriptor.ServiceDescriptor(
  name='ClientNamenodeProtocol',
  full_name='hadoop.hdfs.ClientNamenodeProtocol',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=6855,
  serialized_end=12239,
  methods=[
  _descriptor.MethodDescriptor(
    name='getBlockLocations',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getBlockLocations',
    index=0,
    containing_service=None,
    input_type=_GETBLOCKLOCATIONSREQUESTPROTO,
    output_type=_GETBLOCKLOCATIONSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getServerDefaults',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getServerDefaults',
    index=1,
    containing_service=None,
    input_type=_GETSERVERDEFAULTSREQUESTPROTO,
    output_type=_GETSERVERDEFAULTSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='create',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.create',
    index=2,
    containing_service=None,
    input_type=_CREATEREQUESTPROTO,
    output_type=_CREATERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='append',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.append',
    index=3,
    containing_service=None,
    input_type=_APPENDREQUESTPROTO,
    output_type=_APPENDRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setReplication',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setReplication',
    index=4,
    containing_service=None,
    input_type=_SETREPLICATIONREQUESTPROTO,
    output_type=_SETREPLICATIONRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setPermission',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setPermission',
    index=5,
    containing_service=None,
    input_type=_SETPERMISSIONREQUESTPROTO,
    output_type=_SETPERMISSIONRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setOwner',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setOwner',
    index=6,
    containing_service=None,
    input_type=_SETOWNERREQUESTPROTO,
    output_type=_SETOWNERRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='abandonBlock',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.abandonBlock',
    index=7,
    containing_service=None,
    input_type=_ABANDONBLOCKREQUESTPROTO,
    output_type=_ABANDONBLOCKRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='addBlock',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.addBlock',
    index=8,
    containing_service=None,
    input_type=_ADDBLOCKREQUESTPROTO,
    output_type=_ADDBLOCKRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getAdditionalDatanode',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getAdditionalDatanode',
    index=9,
    containing_service=None,
    input_type=_GETADDITIONALDATANODEREQUESTPROTO,
    output_type=_GETADDITIONALDATANODERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='complete',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.complete',
    index=10,
    containing_service=None,
    input_type=_COMPLETEREQUESTPROTO,
    output_type=_COMPLETERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='reportBadBlocks',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.reportBadBlocks',
    index=11,
    containing_service=None,
    input_type=_REPORTBADBLOCKSREQUESTPROTO,
    output_type=_REPORTBADBLOCKSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='concat',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.concat',
    index=12,
    containing_service=None,
    input_type=_CONCATREQUESTPROTO,
    output_type=_CONCATRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='rename',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.rename',
    index=13,
    containing_service=None,
    input_type=_RENAMEREQUESTPROTO,
    output_type=_RENAMERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='rename2',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.rename2',
    index=14,
    containing_service=None,
    input_type=_RENAME2REQUESTPROTO,
    output_type=_RENAME2RESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='delete',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.delete',
    index=15,
    containing_service=None,
    input_type=_DELETEREQUESTPROTO,
    output_type=_DELETERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='mkdirs',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.mkdirs',
    index=16,
    containing_service=None,
    input_type=_MKDIRSREQUESTPROTO,
    output_type=_MKDIRSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getListing',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getListing',
    index=17,
    containing_service=None,
    input_type=_GETLISTINGREQUESTPROTO,
    output_type=_GETLISTINGRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='renewLease',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.renewLease',
    index=18,
    containing_service=None,
    input_type=_RENEWLEASEREQUESTPROTO,
    output_type=_RENEWLEASERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='recoverLease',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.recoverLease',
    index=19,
    containing_service=None,
    input_type=_RECOVERLEASEREQUESTPROTO,
    output_type=_RECOVERLEASERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getFsStats',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getFsStats',
    index=20,
    containing_service=None,
    input_type=_GETFSSTATUSREQUESTPROTO,
    output_type=_GETFSSTATSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getDatanodeReport',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getDatanodeReport',
    index=21,
    containing_service=None,
    input_type=_GETDATANODEREPORTREQUESTPROTO,
    output_type=_GETDATANODEREPORTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getPreferredBlockSize',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getPreferredBlockSize',
    index=22,
    containing_service=None,
    input_type=_GETPREFERREDBLOCKSIZEREQUESTPROTO,
    output_type=_GETPREFERREDBLOCKSIZERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setSafeMode',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setSafeMode',
    index=23,
    containing_service=None,
    input_type=_SETSAFEMODEREQUESTPROTO,
    output_type=_SETSAFEMODERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='saveNamespace',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.saveNamespace',
    index=24,
    containing_service=None,
    input_type=_SAVENAMESPACEREQUESTPROTO,
    output_type=_SAVENAMESPACERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='rollEdits',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.rollEdits',
    index=25,
    containing_service=None,
    input_type=_ROLLEDITSREQUESTPROTO,
    output_type=_ROLLEDITSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='restoreFailedStorage',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.restoreFailedStorage',
    index=26,
    containing_service=None,
    input_type=_RESTOREFAILEDSTORAGEREQUESTPROTO,
    output_type=_RESTOREFAILEDSTORAGERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='refreshNodes',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.refreshNodes',
    index=27,
    containing_service=None,
    input_type=_REFRESHNODESREQUESTPROTO,
    output_type=_REFRESHNODESRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='finalizeUpgrade',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.finalizeUpgrade',
    index=28,
    containing_service=None,
    input_type=_FINALIZEUPGRADEREQUESTPROTO,
    output_type=_FINALIZEUPGRADERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listCorruptFileBlocks',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.listCorruptFileBlocks',
    index=29,
    containing_service=None,
    input_type=_LISTCORRUPTFILEBLOCKSREQUESTPROTO,
    output_type=_LISTCORRUPTFILEBLOCKSRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='metaSave',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.metaSave',
    index=30,
    containing_service=None,
    input_type=_METASAVEREQUESTPROTO,
    output_type=_METASAVERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getFileInfo',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getFileInfo',
    index=31,
    containing_service=None,
    input_type=_GETFILEINFOREQUESTPROTO,
    output_type=_GETFILEINFORESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getFileLinkInfo',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getFileLinkInfo',
    index=32,
    containing_service=None,
    input_type=_GETFILELINKINFOREQUESTPROTO,
    output_type=_GETFILELINKINFORESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getContentSummary',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getContentSummary',
    index=33,
    containing_service=None,
    input_type=_GETCONTENTSUMMARYREQUESTPROTO,
    output_type=_GETCONTENTSUMMARYRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setQuota',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setQuota',
    index=34,
    containing_service=None,
    input_type=_SETQUOTAREQUESTPROTO,
    output_type=_SETQUOTARESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='fsync',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.fsync',
    index=35,
    containing_service=None,
    input_type=_FSYNCREQUESTPROTO,
    output_type=_FSYNCRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setTimes',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setTimes',
    index=36,
    containing_service=None,
    input_type=_SETTIMESREQUESTPROTO,
    output_type=_SETTIMESRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='createSymlink',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.createSymlink',
    index=37,
    containing_service=None,
    input_type=_CREATESYMLINKREQUESTPROTO,
    output_type=_CREATESYMLINKRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getLinkTarget',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getLinkTarget',
    index=38,
    containing_service=None,
    input_type=_GETLINKTARGETREQUESTPROTO,
    output_type=_GETLINKTARGETRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='updateBlockForPipeline',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.updateBlockForPipeline',
    index=39,
    containing_service=None,
    input_type=_UPDATEBLOCKFORPIPELINEREQUESTPROTO,
    output_type=_UPDATEBLOCKFORPIPELINERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='updatePipeline',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.updatePipeline',
    index=40,
    containing_service=None,
    input_type=_UPDATEPIPELINEREQUESTPROTO,
    output_type=_UPDATEPIPELINERESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getDelegationToken',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getDelegationToken',
    index=41,
    containing_service=None,
    input_type=Security__pb2._GETDELEGATIONTOKENREQUESTPROTO,
    output_type=Security__pb2._GETDELEGATIONTOKENRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='renewDelegationToken',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.renewDelegationToken',
    index=42,
    containing_service=None,
    input_type=Security__pb2._RENEWDELEGATIONTOKENREQUESTPROTO,
    output_type=Security__pb2._RENEWDELEGATIONTOKENRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='cancelDelegationToken',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.cancelDelegationToken',
    index=43,
    containing_service=None,
    input_type=Security__pb2._CANCELDELEGATIONTOKENREQUESTPROTO,
    output_type=Security__pb2._CANCELDELEGATIONTOKENRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setBalancerBandwidth',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.setBalancerBandwidth',
    index=44,
    containing_service=None,
    input_type=_SETBALANCERBANDWIDTHREQUESTPROTO,
    output_type=_SETBALANCERBANDWIDTHRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getDataEncryptionKey',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getDataEncryptionKey',
    index=45,
    containing_service=None,
    input_type=_GETDATAENCRYPTIONKEYREQUESTPROTO,
    output_type=_GETDATAENCRYPTIONKEYRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='createSnapshot',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.createSnapshot',
    index=46,
    containing_service=None,
    input_type=_CREATESNAPSHOTREQUESTPROTO,
    output_type=_CREATESNAPSHOTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='renameSnapshot',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.renameSnapshot',
    index=47,
    containing_service=None,
    input_type=_RENAMESNAPSHOTREQUESTPROTO,
    output_type=_RENAMESNAPSHOTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='allowSnapshot',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.allowSnapshot',
    index=48,
    containing_service=None,
    input_type=_ALLOWSNAPSHOTREQUESTPROTO,
    output_type=_ALLOWSNAPSHOTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='disallowSnapshot',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.disallowSnapshot',
    index=49,
    containing_service=None,
    input_type=_DISALLOWSNAPSHOTREQUESTPROTO,
    output_type=_DISALLOWSNAPSHOTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getSnapshottableDirListing',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getSnapshottableDirListing',
    index=50,
    containing_service=None,
    input_type=_GETSNAPSHOTTABLEDIRLISTINGREQUESTPROTO,
    output_type=_GETSNAPSHOTTABLEDIRLISTINGRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='deleteSnapshot',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.deleteSnapshot',
    index=51,
    containing_service=None,
    input_type=_DELETESNAPSHOTREQUESTPROTO,
    output_type=_DELETESNAPSHOTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getSnapshotDiffReport',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.getSnapshotDiffReport',
    index=52,
    containing_service=None,
    input_type=_GETSNAPSHOTDIFFREPORTREQUESTPROTO,
    output_type=_GETSNAPSHOTDIFFREPORTRESPONSEPROTO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='isFileClosed',
    full_name='hadoop.hdfs.ClientNamenodeProtocol.isFileClosed',
    index=53,
    containing_service=None,
    input_type=_ISFILECLOSEDREQUESTPROTO,
    output_type=_ISFILECLOSEDRESPONSEPROTO,
    options=None,
  ),
])

ClientNamenodeProtocol = service_reflection.GeneratedServiceType('ClientNamenodeProtocol', (_service.Service,), dict(
  DESCRIPTOR = _CLIENTNAMENODEPROTOCOL,
  __module__ = 'ClientNamenodeProtocol_pb2'
  ))

ClientNamenodeProtocol_Stub = service_reflection.GeneratedServiceStubType('ClientNamenodeProtocol_Stub', (ClientNamenodeProtocol,), dict(
  DESCRIPTOR = _CLIENTNAMENODEPROTOCOL,
  __module__ = 'ClientNamenodeProtocol_pb2'
  ))


# @@protoc_insertion_point(module_scope)
